# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/error.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/state/v1/error.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%device/heat_pump/state/v1/error.proto\x12\x19\x64\x65vice.heat_pump.state.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe9\x01\n\x05\x45rror\x12\x35\n\x08severity\x18\x01 \x01(\x0e\x32#.device.heat_pump.state.v1.Severity\x12\x36\n\x03\x63\x63v\x18\x02 \x01(\x0e\x32\'.device.heat_pump.state.v1.CcvErrorCodeH\x00\x12\x38\n\x04\x61ira\x18\x03 \x01(\x0e\x32(.device.heat_pump.state.v1.AiraErrorCodeH\x00\x12/\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\n\x04\x63ode*e\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x15\n\x11SEVERITY_CRITICAL\x10\x01\x12\x12\n\x0eSEVERITY_ERROR\x10\x02\x12\x14\n\x10SEVERITY_WARNING\x10\x03*\x81!\n\x0c\x43\x63vErrorCode\x12\x1e\n\x1a\x43\x43V_ERROR_CODE_UNSPECIFIED\x10\x00\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_AMBIENT_AL_DC\x10\xc8\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_AMBIENT_AL_SC\x10\xc9\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_HP_OUT_AL_DC\x10\xca\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_HP_OUT_AL_SC\x10\xcb\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_HP_IN_AL_DC\x10\xcc\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_HP_IN_AL_SC\x10\xcd\x01\x12\'\n\"CCV_ERROR_CODE_ST_INNER_COIL_AL_DC\x10\xce\x01\x12\'\n\"CCV_ERROR_CODE_ST_INNER_COIL_AL_SC\x10\xcf\x01\x12%\n CCV_ERROR_CODE_ST_DHW_TANK_AL_DC\x10\xd0\x01\x12%\n CCV_ERROR_CODE_ST_DHW_TANK_AL_SC\x10\xd1\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_SUPPLY_AL_DC\x10\xd2\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_SUPPLY_AL_SC\x10\xd3\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_SUPPLY1_AL_DC\x10\xd4\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_SUPPLY1_AL_SC\x10\xd5\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_SUPPLY2_AL_DC\x10\xd6\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_SUPPLY2_AL_SC\x10\xd7\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_ROOM1_AL_DC\x10\xdc\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_ROOM1_AL_SC\x10\xdd\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_ROOM2_AL_DC\x10\xde\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_ROOM2_AL_SC\x10\xdf\x01\x12?\n;CCV_ERROR_CODE_REGLERING_KOMPRESSOR_FINNS_STOPPANDE_VP_LARM\x10\x38\x12)\n$CCV_ERROR_CODE_MODBUS_KOMM_ALARM_ELM\x10\xb5\x01\x12%\n!CCV_ERROR_CODE_ST_SUPPLY1_AL_HIGH\x10x\x12%\n!CCV_ERROR_CODE_ST_SUPPLY2_AL_HIGH\x10z\x12\'\n\"CCV_ERROR_CODE_WARNING_FLOW_TO_LOW\x10\x80\x01\x12$\n CCV_ERROR_CODE_ALARM_FLOW_TO_LOW\x10\x7f\x12-\n(CCV_ERROR_CODE_ST_HP_OUT_AL_HIGH_3_TIMES\x10\xa0\x01\x12%\n CCV_ERROR_CODE_ST_HP_OUT_AL_HIGH\x10\xa1\x01\x12,\n\'CCV_ERROR_CODE_ST_HP_OUT_AL_LOW_3_TIMES\x10\xa2\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_HP_OUT_AL_LOW\x10\xa3\x01\x12,\n\'CCV_ERROR_CODE_ST_HP_IN_AL_HIGH_3_TIMES\x10\xa5\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_HP_IN_AL_HIGH\x10\xa6\x01\x12+\n&CCV_ERROR_CODE_ST_HP_IN_AL_LOW_3_TIMES\x10\xa7\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_HP_IN_AL_LOW\x10\xa8\x01\x12\x30\n+CCV_ERROR_CODE_ST_INNER_COIL_AL_LOW_3_TIMES\x10\xa9\x01\x12(\n#CCV_ERROR_CODE_ST_INNER_COIL_AL_LOW\x10\xaa\x01\x12\x30\n+CCV_ERROR_CODE_WARNING_LEGIO_NOT_SUCCESSFUL\x10\xad\x01\x12(\n#CCV_ERROR_CODE_FLOW_LEVEL_2_TOO_LOW\x10\xb6\x01\x12\x30\n+CCV_ERROR_CODE_FLOW_LEVEL_2_TOO_LOW_3_TIMES\x10\xb7\x01\x12(\n#CCV_ERROR_CODE_FLOW_LEVEL_1_TOO_LOW\x10\xb8\x01\x12\x30\n+CCV_ERROR_CODE_FLOW_LEVEL_1_TOO_LOW_3_TIMES\x10\xb9\x01\x12-\n(CCV_ERROR_CODE_WARNING_ANTIFREEZE_ACTIVE\x10\xba\x01\x12.\n)CCV_ERROR_CODE_DEFROST_OUTLET_LOW_3_TIMES\x10\xbd\x01\x12&\n!CCV_ERROR_CODE_DEFROST_OUTLET_LOW\x10\xbe\x01\x12)\n$CCV_ERROR_CODE_ES_MEGMET_SUM_C_ALARM\x10\xab\x02\x12)\n$CCV_ERROR_CODE_ES_MEGMET_SUM_E_ALARM\x10\xac\x02\x12*\n%CCV_ERROR_CODE_ES_MEGMET_SUM_COMERROR\x10\xad\x02\x12(\n#CCV_ERROR_CODE_MAIN_LINE_PROTECTION\x10\xae\x02\x12\x37\n2CCV_ERROR_CODE_COMPRESSOR_PHASE_CURRENT_PROTECTION\x10\xaf\x02\x12)\n$CCV_ERROR_CODE_IPM_MODULE_PROTECTION\x10\xb0\x02\x12\x34\n/CCV_ERROR_CODE_COMPRESSOR_OIL_RETURN_PROTECTION\x10\xb1\x02\x12\x33\n.CCV_ERROR_CODE_HIGH_PRESSURE_SWITCH_PROTECTION\x10\xb2\x02\x12\x37\n2CCV_ERROR_CODE_COMPRESSOR_SPEED_DOWN_HIGH_PRESSURE\x10\xb3\x02\x12\x33\n.CCV_ERROR_CODE_FIRST_START_PRE_HEAT_PROTECTION\x10\xb4\x02\x12\x34\n/CCV_ERROR_CODE_OUTDOOR_GAS_DISCHARGE_PROTECTION\x10\xb5\x02\x12\x36\n1CCV_ERROR_CODE_OUTDOOR_EVAPORATOR_COIL_PROTECTION\x10\xb6\x02\x12\'\n\"CCV_ERROR_CODE_AC_HIGH_LOW_VOLTAGE\x10\xb7\x02\x12\x32\n-CCV_ERROR_CODE_FAILURE_CAUSED_BY_AMBIENT_TEMP\x10\xb8\x02\x12\x32\n-CCV_ERROR_CODE_FREQUNCY_LIMIT_BY_AMBIENT_TEMP\x10\xb9\x02\x12\x32\n-CCV_ERROR_CODE_LOW_PRESSURE_SWITCH_PROTECTION\x10\xba\x02\x12\x36\n1CCV_ERROR_CODE_COMPRESSOR_SPEED_DOWN_LOW_PRESSURE\x10\xbb\x02\x12\x30\n+CCV_ERROR_CODE_OUTDOOR_AMBIENT_TEMP_FAILURE\x10\xbc\x02\x12\x33\n.CCV_ERROR_CODE_OUTDOOR_EVAPORATOR_COIL_FAILURE\x10\xbd\x02\x12\x31\n,CCV_ERROR_CODE_OUTDOOR_GAS_DISCHARGE_FAILURE\x10\xbe\x02\x12.\n)CCV_ERROR_CODE_OUTDOOR_GAS_RETURN_FAILURE\x10\xbf\x02\x12/\n*CCV_ERROR_CODE_EVAPORATOR_PRESSURE_FAILURE\x10\xc0\x02\x12.\n)CCV_ERROR_CODE_CONDENSER_PRESSURE_FAILURE\x10\xc1\x02\x12\x38\n3CCV_ERROR_CODE_HIGH_PRESSURE_SWITCH_LOCK_PROTECTION\x10\xc2\x02\x12\x37\n2CCV_ERROR_CODE_LOW_PRESSURE_SWITCH_LOCK_PROTECTION\x10\xc3\x02\x12$\n\x1f\x43\x43V_ERROR_CODE_DC_FAN_A_FAILURE\x10\xc4\x02\x12$\n\x1f\x43\x43V_ERROR_CODE_DC_FAN_B_FAILURE\x10\xc5\x02\x12\x38\n3CCV_ERROR_CODE_EVAPORATING_PRESSURE_LOCK_PROTECTION\x10\xc6\x02\x12\x36\n1CCV_ERROR_CODE_CONDENSER_PRESSURE_LOCK_PROTECTION\x10\xc7\x02\x12:\n5CCV_ERROR_CODE_MASTER_AND_SLAVE_COMMUNICATION_FAILURE\x10\xc8\x02\x12M\nHCCV_ERROR_CODE_OUTDOOR_MAIN_CONTROL_PCB_AND_MODULE_COMMUNICATION_FAILURE\x10\xc9\x02\x12\x34\n/CCV_ERROR_CODE_COMPRESSOR_PHASE_CURRENT_FAILURE\x10\xca\x02\x12\x35\n0CCV_ERROR_CODE_COMPRESSOR_PHASE_CURRENT_OVERLOAD\x10\xcb\x02\x12-\n(CCV_ERROR_CODE_COMPRESSOR_DRIVER_FAILURE\x10\xcc\x02\x12<\n7CCV_ERROR_CODE_MODULE_VDC_OVER_HIGH_LOW_VOLTAGE_FAILURE\x10\xcd\x02\x12&\n!CCV_ERROR_CODE_AC_CURRENT_FAILURE\x10\xce\x02\x12\"\n\x1d\x43\x43V_ERROR_CODE_EEPROM_FAILURE\x10\xcf\x02\x12)\n$CCV_ERROR_CODE_FAN_DRIVE_PCB_FAILURE\x10\xd0\x02\x12,\n\'CCV_ERROR_CODE_INLET_WATER_TEMP_FAILURE\x10\xd1\x02\x12-\n(CCV_ERROR_CODE_OUTLET_WATER_TEMP_FAILURE\x10\xd2\x02\x12+\n&CCV_ERROR_CODE_INNER_COIL_TEMP_FAILURE\x10\xd3\x02\x12)\n$CCV_ERROR_CODE_DC_WATER_PUMP_FAILURE\x10\xd4\x02\x12,\n\'CCV_ERROR_CODE_COMPRESSOR_STOPPED_ALARM\x10\xdd\x02\x12\x32\n-CCV_ERROR_CODE_COMPRESSOR_STOPPED_OUTLET_TEMP\x10\xde\x02\x12\x36\n1CCV_ERROR_CODE_COMPRESSOR_STOPPED_INNER_COIL_TEMP\x10\xdf\x02\x12/\n*CCV_ERROR_CODE_ST_SUPPLY1_AL_CRITICAL_HIGH\x10\xc2\x01\x12/\n*CCV_ERROR_CODE_ST_SUPPLY2_AL_CRITICAL_HIGH\x10\xc3\x01*\xe0\x01\n\rAiraErrorCode\x12\x1f\n\x1b\x41IRA_ERROR_CODE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x41IRA_ERROR_CODE_WIFI_RSSI\x10\x01\x12+\n\'AIRA_ERROR_CODE_ANTI_LEGIONELLA_TIMEOUT\x10\x02\x12\x30\n,AIRA_ERROR_CODE_THERMOSTAT_DISCONNECT_ZONE_1\x10\x03\x12\x30\n,AIRA_ERROR_CODE_THERMOSTAT_DISCONNECT_ZONE_2\x10\x04\x42\xbc\x01\n+com.aira.contract.device.heat_pump.state.v1B\nErrorProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.error_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.state.v1B\nErrorProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_SEVERITY']._serialized_start=337
  _globals['_SEVERITY']._serialized_end=438
  _globals['_CCVERRORCODE']._serialized_start=441
  _globals['_CCVERRORCODE']._serialized_end=4666
  _globals['_AIRAERRORCODE']._serialized_start=4669
  _globals['_AIRAERRORCODE']._serialized_end=4893
  _globals['_ERROR']._serialized_start=102
  _globals['_ERROR']._serialized_end=335
# @@protoc_insertion_point(module_scope)