# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/cloud/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/cloud/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...command.v1 import command_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_command__pb2
from ...command.v1 import command_progress_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_command__progress__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from .....util.v1 import type_of_day_pb2 as util_dot_v1_dot_type__of__day__pb2
from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from .....util.v2 import market_pb2 as util_dot_v2_dot_market__pb2
from .....util.v2 import uuid_pb2 as util_dot_v2_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'device/heat_pump/cloud/v1/service.proto\x12\x19\x64\x65vice.heat_pump.cloud.v1\x1a)device/heat_pump/command/v1/command.proto\x1a\x32\x64\x65vice/heat_pump/command/v1/command_progress.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19util/v1/type_of_day.proto\x1a\x12util/v1/uuid.proto\x1a\x14util/v2/market.proto\x1a\x12util/v2/uuid.proto\"p\n\x12SendCommandRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x35\n\x07\x63ommand\x18\x02 \x01(\x0b\x32$.device.heat_pump.command.v1.Command\"8\n\x13SendCommandResponse\x12!\n\ncommand_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"A\n\x1cStreamCommandProgressRequest\x12!\n\ncommand_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"g\n\x1dStreamCommandProgressResponse\x12\x46\n\x10\x63ommand_progress\x18\x01 \x01(\x0b\x32,.device.heat_pump.command.v1.CommandProgress\"\xaa\x01\n\x11ScheduledAwayMode\x12#\n\x0cheat_pump_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\tJ\x04\x08\x01\x10\x02\"d\n\x17ScheduleAwayModeRequest\x12I\n\x13scheduled_away_mode\x18\x01 \x01(\x0b\x32,.device.heat_pump.cloud.v1.ScheduledAwayMode\"I\n\x18ScheduleAwayModeResponse\x12-\n\x16scheduled_away_mode_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"B\n\x1bGetScheduledAwayModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"i\n\x1cGetScheduledAwayModeResponse\x12I\n\x13scheduled_away_mode\x18\x01 \x01(\x0b\x32,.device.heat_pump.cloud.v1.ScheduledAwayMode\"E\n\x1e\x44\x65leteScheduledAwayModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\'\n\x1f\x44\x65leteScheduledAwayModeResponseJ\x04\x08\x01\x10\x02\"?\n\x18ScheduleNightModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\x1b\n\x19ScheduleNightModeResponse\"F\n\x1f\x44\x65leteScheduledNightModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\"\n DeleteScheduledNightModeResponse\"\x9b\x01\n\x15SetDhwScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12<\n\x07\x65ntries\x18\x02 \x03(\x0b\x32+.device.heat_pump.cloud.v1.DhwScheduleEntry\x12\x1f\n\x06market\x18\x03 \x01(\x0e\x32\x0f.util.v2.Market\"\x18\n\x16SetDhwScheduleResponse\"\xb1\x01\n\x10\x44hwScheduleEntry\x12\x17\n\nstart_hour\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x15\n\x08\x65nd_hour\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\'\n\x0btype_of_day\x18\x03 \x01(\x0e\x32\x12.util.v1.TypeOfDay\x12\x18\n\x0btemperature\x18\x04 \x01(\rH\x02\x88\x01\x01\x42\r\n\x0b_start_hourB\x0b\n\t_end_hourB\x0e\n\x0c_temperature\"<\n\x15GetDhwScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"V\n\x16GetDhwScheduleResponse\x12<\n\x07\x65ntries\x18\x01 \x03(\x0b\x32+.device.heat_pump.cloud.v1.DhwScheduleEntry\"?\n\x18\x44\x65leteDhwScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\x1b\n\x19\x44\x65leteDhwScheduleResponse\"\xae\x01\n\x1cSetLegionellaScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x36\n\rnext_run_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x1f\n\x06market\x18\x03 \x01(\x0e\x32\x0f.util.v2.MarketB\x10\n\x0e_next_run_time\"\x1f\n\x1dSetLegionellaScheduleResponse\"C\n\x1cGetLegionellaScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\x8e\x01\n\x1dGetLegionellaScheduleResponse\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x36\n\rnext_run_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x42\x10\n\x0e_next_run_time\"F\n\x1f\x44\x65leteLegionellaScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\"\n DeleteLegionellaScheduleResponse2\xe1\r\n\x14HeatPumpCloudService\x12l\n\x0bSendCommand\x12-.device.heat_pump.cloud.v1.SendCommandRequest\x1a..device.heat_pump.cloud.v1.SendCommandResponse\x12\x8c\x01\n\x15StreamCommandProgress\x12\x37.device.heat_pump.cloud.v1.StreamCommandProgressRequest\x1a\x38.device.heat_pump.cloud.v1.StreamCommandProgressResponse0\x01\x12{\n\x10ScheduleAwayMode\x12\x32.device.heat_pump.cloud.v1.ScheduleAwayModeRequest\x1a\x33.device.heat_pump.cloud.v1.ScheduleAwayModeResponse\x12\x87\x01\n\x14GetScheduledAwayMode\x12\x36.device.heat_pump.cloud.v1.GetScheduledAwayModeRequest\x1a\x37.device.heat_pump.cloud.v1.GetScheduledAwayModeResponse\x12\x90\x01\n\x17\x44\x65leteScheduledAwayMode\x12\x39.device.heat_pump.cloud.v1.DeleteScheduledAwayModeRequest\x1a:.device.heat_pump.cloud.v1.DeleteScheduledAwayModeResponse\x12~\n\x11ScheduleNightMode\x12\x33.device.heat_pump.cloud.v1.ScheduleNightModeRequest\x1a\x34.device.heat_pump.cloud.v1.ScheduleNightModeResponse\x12\x93\x01\n\x18\x44\x65leteScheduledNightMode\x12:.device.heat_pump.cloud.v1.DeleteScheduledNightModeRequest\x1a;.device.heat_pump.cloud.v1.DeleteScheduledNightModeResponse\x12u\n\x0eSetDhwSchedule\x12\x30.device.heat_pump.cloud.v1.SetDhwScheduleRequest\x1a\x31.device.heat_pump.cloud.v1.SetDhwScheduleResponse\x12u\n\x0eGetDhwSchedule\x12\x30.device.heat_pump.cloud.v1.GetDhwScheduleRequest\x1a\x31.device.heat_pump.cloud.v1.GetDhwScheduleResponse\x12~\n\x11\x44\x65leteDhwSchedule\x12\x33.device.heat_pump.cloud.v1.DeleteDhwScheduleRequest\x1a\x34.device.heat_pump.cloud.v1.DeleteDhwScheduleResponse\x12\x8a\x01\n\x15SetLegionellaSchedule\x12\x37.device.heat_pump.cloud.v1.SetLegionellaScheduleRequest\x1a\x38.device.heat_pump.cloud.v1.SetLegionellaScheduleResponse\x12\x8a\x01\n\x15GetLegionellaSchedule\x12\x37.device.heat_pump.cloud.v1.GetLegionellaScheduleRequest\x1a\x38.device.heat_pump.cloud.v1.GetLegionellaScheduleResponse\x12\x93\x01\n\x18\x44\x65leteLegionellaSchedule\x12:.device.heat_pump.cloud.v1.DeleteLegionellaScheduleRequest\x1a;.device.heat_pump.cloud.v1.DeleteLegionellaScheduleResponseB\xbe\x01\n+com.aira.contract.device.heat_pump.cloud.v1B\x0cServiceProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x18\x44\x65vice.HeatPump.Cloud.V1\xca\x02\x18\x44\x65vice\\HeatPump\\Cloud\\V1\xe2\x02$Device\\HeatPump\\Cloud\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::Cloud::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.cloud.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.cloud.v1B\014ServiceProtoP\001\242\002\003DHC\252\002\030Device.HeatPump.Cloud.V1\312\002\030Device\\HeatPump\\Cloud\\V1\342\002$Device\\HeatPump\\Cloud\\V1\\GPBMetadata\352\002\033Device::HeatPump::Cloud::V1'
  _globals['_SENDCOMMANDREQUEST']._serialized_start=287
  _globals['_SENDCOMMANDREQUEST']._serialized_end=399
  _globals['_SENDCOMMANDRESPONSE']._serialized_start=401
  _globals['_SENDCOMMANDRESPONSE']._serialized_end=457
  _globals['_STREAMCOMMANDPROGRESSREQUEST']._serialized_start=459
  _globals['_STREAMCOMMANDPROGRESSREQUEST']._serialized_end=524
  _globals['_STREAMCOMMANDPROGRESSRESPONSE']._serialized_start=526
  _globals['_STREAMCOMMANDPROGRESSRESPONSE']._serialized_end=629
  _globals['_SCHEDULEDAWAYMODE']._serialized_start=632
  _globals['_SCHEDULEDAWAYMODE']._serialized_end=802
  _globals['_SCHEDULEAWAYMODEREQUEST']._serialized_start=804
  _globals['_SCHEDULEAWAYMODEREQUEST']._serialized_end=904
  _globals['_SCHEDULEAWAYMODERESPONSE']._serialized_start=906
  _globals['_SCHEDULEAWAYMODERESPONSE']._serialized_end=979
  _globals['_GETSCHEDULEDAWAYMODEREQUEST']._serialized_start=981
  _globals['_GETSCHEDULEDAWAYMODEREQUEST']._serialized_end=1047
  _globals['_GETSCHEDULEDAWAYMODERESPONSE']._serialized_start=1049
  _globals['_GETSCHEDULEDAWAYMODERESPONSE']._serialized_end=1154
  _globals['_DELETESCHEDULEDAWAYMODEREQUEST']._serialized_start=1156
  _globals['_DELETESCHEDULEDAWAYMODEREQUEST']._serialized_end=1225
  _globals['_DELETESCHEDULEDAWAYMODERESPONSE']._serialized_start=1227
  _globals['_DELETESCHEDULEDAWAYMODERESPONSE']._serialized_end=1266
  _globals['_SCHEDULENIGHTMODEREQUEST']._serialized_start=1268
  _globals['_SCHEDULENIGHTMODEREQUEST']._serialized_end=1331
  _globals['_SCHEDULENIGHTMODERESPONSE']._serialized_start=1333
  _globals['_SCHEDULENIGHTMODERESPONSE']._serialized_end=1360
  _globals['_DELETESCHEDULEDNIGHTMODEREQUEST']._serialized_start=1362
  _globals['_DELETESCHEDULEDNIGHTMODEREQUEST']._serialized_end=1432
  _globals['_DELETESCHEDULEDNIGHTMODERESPONSE']._serialized_start=1434
  _globals['_DELETESCHEDULEDNIGHTMODERESPONSE']._serialized_end=1468
  _globals['_SETDHWSCHEDULEREQUEST']._serialized_start=1471
  _globals['_SETDHWSCHEDULEREQUEST']._serialized_end=1626
  _globals['_SETDHWSCHEDULERESPONSE']._serialized_start=1628
  _globals['_SETDHWSCHEDULERESPONSE']._serialized_end=1652
  _globals['_DHWSCHEDULEENTRY']._serialized_start=1655
  _globals['_DHWSCHEDULEENTRY']._serialized_end=1832
  _globals['_GETDHWSCHEDULEREQUEST']._serialized_start=1834
  _globals['_GETDHWSCHEDULEREQUEST']._serialized_end=1894
  _globals['_GETDHWSCHEDULERESPONSE']._serialized_start=1896
  _globals['_GETDHWSCHEDULERESPONSE']._serialized_end=1982
  _globals['_DELETEDHWSCHEDULEREQUEST']._serialized_start=1984
  _globals['_DELETEDHWSCHEDULEREQUEST']._serialized_end=2047
  _globals['_DELETEDHWSCHEDULERESPONSE']._serialized_start=2049
  _globals['_DELETEDHWSCHEDULERESPONSE']._serialized_end=2076
  _globals['_SETLEGIONELLASCHEDULEREQUEST']._serialized_start=2079
  _globals['_SETLEGIONELLASCHEDULEREQUEST']._serialized_end=2253
  _globals['_SETLEGIONELLASCHEDULERESPONSE']._serialized_start=2255
  _globals['_SETLEGIONELLASCHEDULERESPONSE']._serialized_end=2286
  _globals['_GETLEGIONELLASCHEDULEREQUEST']._serialized_start=2288
  _globals['_GETLEGIONELLASCHEDULEREQUEST']._serialized_end=2355
  _globals['_GETLEGIONELLASCHEDULERESPONSE']._serialized_start=2358
  _globals['_GETLEGIONELLASCHEDULERESPONSE']._serialized_end=2500
  _globals['_DELETELEGIONELLASCHEDULEREQUEST']._serialized_start=2502
  _globals['_DELETELEGIONELLASCHEDULEREQUEST']._serialized_end=2572
  _globals['_DELETELEGIONELLASCHEDULERESPONSE']._serialized_start=2574
  _globals['_DELETELEGIONELLASCHEDULERESPONSE']._serialized_end=2608
  _globals['_HEATPUMPCLOUDSERVICE']._serialized_start=2611
  _globals['_HEATPUMPCLOUDSERVICE']._serialized_end=4372
# @@protoc_insertion_point(module_scope)