# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/config/v1/ccv/v1/ccv_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/config/v1/ccv/v1/ccv_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import heat_curve_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_ccv_dot_v1_dot_heat__curve__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2device/heat_pump/config/v1/ccv/v1/ccv_config.proto\x12!device.heat_pump.config.v1.ccv.v1\x1a\x32\x64\x65vice/heat_pump/config/v1/ccv/v1/heat_curve.proto\"\x81\x08\n\rSensorSources\x12\x34\n\'outdoor_unit_ambient_temperature_source\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x33\n&outdoor_unit_supply_temperature_source\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x33\n&outdoor_unit_return_temperature_source\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x37\n*outdoor_unit_inner_coil_temperature_source\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x34\n\'indoor_unit_dhw_tank_temperature_source\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x32\n%indoor_unit_supply_temperature_source\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x39\n,indoor_unit_supply_temperature_zone_1_source\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x39\n,indoor_unit_supply_temperature_zone_2_source\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x37\n*indoor_unit_room_temperature_zone_1_source\x18\t \x01(\rH\x08\x88\x01\x01\x12\x37\n*indoor_unit_room_temperature_zone_2_source\x18\n \x01(\rH\t\x88\x01\x01\x42*\n(_outdoor_unit_ambient_temperature_sourceB)\n\'_outdoor_unit_supply_temperature_sourceB)\n\'_outdoor_unit_return_temperature_sourceB-\n+_outdoor_unit_inner_coil_temperature_sourceB*\n(_indoor_unit_dhw_tank_temperature_sourceB(\n&_indoor_unit_supply_temperature_sourceB/\n-_indoor_unit_supply_temperature_zone_1_sourceB/\n-_indoor_unit_supply_temperature_zone_2_sourceB-\n+_indoor_unit_room_temperature_zone_1_sourceB-\n+_indoor_unit_room_temperature_zone_2_source\"\x86\n\n\x12\x43ompressorSettings\x12+\n\x1eminimum_time_start_start_cycle\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12*\n\x1dminimum_time_stop_start_cycle\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12&\n\x19p0_compressor_prerun_time\x18\x05 \x01(\x05H\x02\x88\x01\x01\x12,\n\x1f\x64hw_diverting_valve_prerun_time\x18\x06 \x01(\x05H\x03\x88\x01\x01\x12(\n\x1bp0_compressor_afterrun_time\x18\x07 \x01(\x05H\x04\x88\x01\x01\x12*\n\x1d\x64iverting_valve_afterrun_time\x18\x08 \x01(\x05H\x05\x88\x01\x01\x12%\n\x18p0_autostart_temperature\x18\t \x01(\x02H\x06\x88\x01\x01\x12\'\n\x1amaximum_outlet_temperature\x18\n \x01(\x02H\x07\x88\x01\x01\x12\'\n\x1aminimum_outlet_temperature\x18\x0b \x01(\x02H\x08\x88\x01\x01\x12&\n\x19maximum_inlet_temperature\x18\x0c \x01(\x02H\t\x88\x01\x01\x12&\n\x19minimum_inlet_temperature\x18\r \x01(\x02H\n\x88\x01\x01\x12+\n\x1eminimum_inner_coil_temperature\x18\x0e \x01(\x02H\x0b\x88\x01\x01\x12\"\n\x15\x63ompressor_limit_time\x18\x11 \x01(\x02H\x0c\x88\x01\x01\x12-\n compressor_inner_coil_block_time\x18\x10 \x01(\x05H\r\x88\x01\x01\x12\'\n\x16\x64\x65precated_speed_level\x18\x01 \x01(\x05\x42\x02\x18\x01H\x0e\x88\x01\x01\x12(\n\x17\x64\x65precated_working_mode\x18\x02 \x01(\x05\x42\x02\x18\x01H\x0f\x88\x01\x01\x12\x31\n deprecated_compressor_limit_time\x18\x0f \x01(\x05\x42\x02\x18\x01H\x10\x88\x01\x01\x42!\n\x1f_minimum_time_start_start_cycleB \n\x1e_minimum_time_stop_start_cycleB\x1c\n\x1a_p0_compressor_prerun_timeB\"\n _dhw_diverting_valve_prerun_timeB\x1e\n\x1c_p0_compressor_afterrun_timeB \n\x1e_diverting_valve_afterrun_timeB\x1b\n\x19_p0_autostart_temperatureB\x1d\n\x1b_maximum_outlet_temperatureB\x1d\n\x1b_minimum_outlet_temperatureB\x1c\n\x1a_maximum_inlet_temperatureB\x1c\n\x1a_minimum_inlet_temperatureB!\n\x1f_minimum_inner_coil_temperatureB\x18\n\x16_compressor_limit_timeB#\n!_compressor_inner_coil_block_timeB\x19\n\x17_deprecated_speed_levelB\x1a\n\x18_deprecated_working_modeB#\n!_deprecated_compressor_limit_time\"\xad\x01\n\x15\x44omesticHotWaterBoost\x12#\n\x16tank_temp_boost_change\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12\x30\n\x1f\x64\x65precated_remaining_boost_time\x18\x01 \x01(\x05\x42\x02\x18\x01H\x01\x88\x01\x01\x42\x19\n\x17_tank_temp_boost_changeB\"\n _deprecated_remaining_boost_time\"U\n\x0bPiRegulator\x12\x15\n\x08p_factor\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x15\n\x08i_factor\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x0b\n\t_p_factorB\x0b\n\t_i_factor\"\xfe\x03\n\rHeatingSystem\x12\x19\n\x0cheating_time\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x15\n\x08\x64hw_time\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x46\n9minimum_inline_heater_cooling_time_before_compressor_stop\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x1c\n\x0fheat_balance_a0\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12\x1c\n\x0fheat_balance_a2\x18\x06 \x01(\x05H\x04\x88\x01\x01\x12\x19\n\x0c\x63ooling_time\x18\x07 \x01(\x05H\x05\x88\x01\x01\x12\x1c\n\x0f\x63ool_balance_k0\x18\x08 \x01(\x05H\x06\x88\x01\x01\x12U\n\x1d\x63ompressor_speed_pi_regulator\x18\t \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulatorB\x0f\n\r_heating_timeB\x0b\n\t_dhw_timeB<\n:_minimum_inline_heater_cooling_time_before_compressor_stopB\x12\n\x10_heat_balance_a0B\x12\n\x10_heat_balance_a2B\x0f\n\r_cooling_timeB\x12\n\x10_cool_balance_k0\"\xc2\x02\n\x12LegionellaSettings\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12 \n\x13interval_time_start\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1f\n\x12interval_time_stop\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1d\n\x10maximum_duration\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1f\n\x12target_temperature\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12\x1a\n\rinterval_days\x18\x06 \x01(\x05H\x05\x88\x01\x01\x42\n\n\x08_enabledB\x16\n\x14_interval_time_startB\x15\n\x13_interval_time_stopB\x13\n\x11_maximum_durationB\x15\n\x13_target_temperatureB\x10\n\x0e_interval_days\"\xee\x04\n\tDhwSystem\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x19\n\x0c\x64hw_setpoint\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x1e\n\x11\x64hw_setpoint_diff\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12G\n\x05\x62oost\x18\x04 \x01(\x0b\x32\x38.device.heat_pump.config.v1.ccv.v1.DomesticHotWaterBoost\x12*\n\x1dtank_temperature_night_change\x18\x05 \x01(\x02H\x03\x88\x01\x01\x12&\n\x19\x63ompressor_speed_dhw_mode\x18\x06 \x01(\x05H\x04\x88\x01\x01\x12)\n\x1cmaximum_setpoint_temperature\x18\x07 \x01(\x02H\x05\x88\x01\x01\x12\x34\n\'unacknowledged_alarm_temperature_change\x18\x08 \x01(\x02H\x06\x88\x01\x01\x12R\n\x13legionella_settings\x18\t \x01(\x0b\x32\x35.device.heat_pump.config.v1.ccv.v1.LegionellaSettingsB\n\n\x08_enabledB\x0f\n\r_dhw_setpointB\x14\n\x12_dhw_setpoint_diffB \n\x1e_tank_temperature_night_changeB\x1c\n\x1a_compressor_speed_dhw_modeB\x1f\n\x1d_maximum_setpoint_temperatureB*\n(_unacknowledged_alarm_temperature_change\"\xe1\x02\n\x0fZoneMixingValve\x12\x1c\n\x0f\x63ontrol_enabled\x18\x04 \x01(\x08H\x00\x88\x01\x01\x12#\n\x16regulation_period_time\x18\x01 \x01(\x05H\x01\x88\x01\x01\x12$\n\x17\x65nd_to_end_running_time\x18\x02 \x01(\x05H\x02\x88\x01\x01\x12.\n!minimum_relay_output_pulse_length\x18\x03 \x01(\x05H\x03\x88\x01\x01\x12\x44\n\x0cpi_regulator\x18\x05 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulatorB\x12\n\x10_control_enabledB\x19\n\x17_regulation_period_timeB\x1a\n\x18_end_to_end_running_timeB$\n\"_minimum_relay_output_pulse_length\"\xba\x02\n\x13ZoneHeatingSettings\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1a\n\rroom_setpoint\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12$\n\x17minimum_supply_setpoint\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12$\n\x17maximum_supply_setpoint\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12O\n\nheat_curve\x18\x05 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearHeatCurveB\n\n\x08_enabledB\x10\n\x0e_room_setpointB\x1a\n\x18_minimum_supply_setpointB\x1a\n\x18_maximum_supply_setpoint\"\xba\x02\n\x13ZoneCoolingSettings\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1a\n\rroom_setpoint\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12$\n\x17minimum_supply_setpoint\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12$\n\x17maximum_supply_setpoint\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12O\n\ncool_curve\x18\x05 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearCoolCurveB\n\n\x08_enabledB\x10\n\x0e_room_setpointB\x1a\n\x18_minimum_supply_setpointB\x1a\n\x18_maximum_supply_setpoint\"\xe9\x03\n\x0cZoneSettings\x12G\n\x07heating\x18\x03 \x01(\x0b\x32\x36.device.heat_pump.config.v1.ccv.v1.ZoneHeatingSettings\x12G\n\x07\x63ooling\x18\x04 \x01(\x0b\x32\x36.device.heat_pump.config.v1.ccv.v1.ZoneCoolingSettings\x12I\n\x11room_pi_regulator\x18\x05 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulator\x12H\n\x0cmixing_valve\x18\x07 \x01(\x0b\x32\x32.device.heat_pump.config.v1.ccv.v1.ZoneMixingValve\x12+\n\x1a\x64\x65precated_control_enabled\x18\x01 \x01(\x08\x42\x02\x18\x01H\x00\x88\x01\x01\x12`\n$deprecated_mixing_valve_pi_regulator\x18\x06 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulatorB\x02\x18\x01\x42\x1d\n\x1b_deprecated_control_enabledJ\x04\x08\x02\x10\x03\"\xa2\x01\n\x08\x41wayMode\x12(\n\x1b\x64hw_tank_temperature_change\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12$\n\x17room_temperature_change\x18\x03 \x01(\x02H\x01\x88\x01\x01\x42\x1e\n\x1c_dhw_tank_temperature_changeB\x1a\n\x18_room_temperature_changeJ\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05\"\xb4\x06\n\x0eHeatingCooling\x12\x16\n\tnum_zones\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x37\n*ambient_temperature_to_enable_heating_mode\x18\x03 \x01(\x02H\x01\x88\x01\x01\x12\x37\n*ambient_temperature_to_enable_cooling_mode\x18\x04 \x01(\x02H\x02\x88\x01\x01\x12\x30\n#minimum_time_heating_cooling_switch\x18\x06 \x01(\x05H\x03\x88\x01\x01\x12\x38\n+supply_temperature_too_high_alarm_temp_diff\x18\x07 \x01(\x02H\x04\x88\x01\x01\x12\x34\n\'supply_temperature_too_high_alarm_delay\x18\x08 \x01(\x05H\x05\x88\x01\x01\x12H\n\x0fsettings_zone_1\x18\t \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.ZoneSettings\x12H\n\x0fsettings_zone_2\x18\n \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.ZoneSettings\x12\x37\n*ambient_temperature_to_allow_inline_heater\x18\x0b \x01(\x02H\x06\x88\x01\x01\x42\x0c\n\n_num_zonesB-\n+_ambient_temperature_to_enable_heating_modeB-\n+_ambient_temperature_to_enable_cooling_modeB&\n$_minimum_time_heating_cooling_switchB.\n,_supply_temperature_too_high_alarm_temp_diffB*\n(_supply_temperature_too_high_alarm_delayB-\n+_ambient_temperature_to_allow_inline_heaterJ\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06\"\xdd\x01\n\x11PumpSpeedSettings\x12\x14\n\x07heating\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07\x63ooling\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x14\n\x07\x64\x65\x66rost\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x14\n\x07minimum\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x17\n\nlegionella\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x10\n\x03\x64hw\x18\x06 \x01(\x05H\x05\x88\x01\x01\x42\n\n\x08_heatingB\n\n\x08_coolingB\n\n\x08_defrostB\n\n\x08_minimumB\r\n\x0b_legionellaB\x06\n\x04_dhw\"\xc7\x01\n\x0f\x41larmThresholds\x12\"\n\x15\x66low_level_1_low_12kw\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12!\n\x14\x66low_level_1_low_8kw\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12!\n\x14\x66low_level_1_low_6kw\x18\x03 \x01(\x02H\x02\x88\x01\x01\x42\x18\n\x16_flow_level_1_low_12kwB\x17\n\x15_flow_level_1_low_8kwB\x17\n\x15_flow_level_1_low_6kw\"\x90\x02\n\x10\x45lectricityMeter\x12V\n\x04type\x18\x01 \x01(\x0e\x32H.device.heat_pump.config.v1.ccv.v1.ElectricityMeter.ElectricityMeterType\"\xa3\x01\n\x14\x45lectricityMeterType\x12&\n\"ELECTRICITY_METER_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45LECTRICITY_METER_TYPE_NONE\x10\x01\x12 \n\x1c\x45LECTRICITY_METER_TYPE_ET340\x10\x02\x12 \n\x1c\x45LECTRICITY_METER_TYPE_ET112\x10\x03\"\xa4\x03\n\x0cInlineHeater\x12Q\n\x06step_1\x18\x01 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\x12Q\n\x06step_2\x18\x02 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\x12Q\n\x06step_3\x18\x03 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\"\x9a\x01\n\x11InlineHeaterUsage\x12#\n\x1fINLINE_HEATER_USAGE_UNSPECIFIED\x10\x00\x12 \n\x1cINLINE_HEATER_USAGE_DISABLED\x10\x01\x12\x1e\n\x1aINLINE_HEATER_USAGE_BACKUP\x10\x02\x12\x1e\n\x1aINLINE_HEATER_USAGE_NORMAL\x10\x03\"-\n\tNightMode\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_enabled\"\xc9\x03\n\nFlowMeters\x12Q\n\x0cmeter_1_type\x18\x01 \x01(\x0e\x32;.device.heat_pump.config.v1.ccv.v1.FlowMeters.FlowMeterType\x12Q\n\x0cmeter_2_type\x18\x02 \x01(\x0e\x32;.device.heat_pump.config.v1.ccv.v1.FlowMeters.FlowMeterType\"\x94\x02\n\rFlowMeterType\x12\x1f\n\x1b\x46LOW_METER_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1d\x46LOW_METER_TYPE_NOT_CONNECTED\x10\x01\x12$\n FLOW_METER_TYPE_HUBA_DN20_BRONZE\x10\x02\x12$\n FLOW_METER_TYPE_HUBA_DN25_BRONZE\x10\x03\x12%\n!FLOW_METER_TYPE_HUBA_DN20_PLASTIC\x10\x04\x12%\n!FLOW_METER_TYPE_HUBA_DN25_PLASTIC\x10\x05\x12%\n!FLOW_METER_TYPE_HUBA_DN10_PLASTIC\x10\x06\"\xc3\x01\n\x11\x45nergyBalanceKick\x12\x1f\n\x12time_between_kicks\x18\x01 \x01(\rH\x00\x88\x01\x01\x12 \n\x13kick_temperature_up\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\"\n\x15kick_temperature_down\x18\x03 \x01(\x02H\x02\x88\x01\x01\x42\x15\n\x13_time_between_kicksB\x16\n\x14_kick_temperature_upB\x18\n\x16_kick_temperature_down\"\xb8\t\n\tCcvConfig\x12H\n\x0esensor_sources\x18\x01 \x01(\x0b\x32\x30.device.heat_pump.config.v1.ccv.v1.SensorSources\x12R\n\x13\x63ompressor_settings\x18\x02 \x01(\x0b\x32\x35.device.heat_pump.config.v1.ccv.v1.CompressorSettings\x12H\n\x0eheating_system\x18\x07 \x01(\x0b\x32\x30.device.heat_pump.config.v1.ccv.v1.HeatingSystem\x12@\n\ndhw_system\x18\x08 \x01(\x0b\x32,.device.heat_pump.config.v1.ccv.v1.DhwSystem\x12>\n\taway_mode\x18\t \x01(\x0b\x32+.device.heat_pump.config.v1.ccv.v1.AwayMode\x12J\n\x0fheating_cooling\x18\n \x01(\x0b\x32\x31.device.heat_pump.config.v1.ccv.v1.HeatingCooling\x12M\n\x11outdoor_unit_size\x18\r \x01(\x0e\x32\x32.device.heat_pump.config.v1.ccv.v1.OutdoorUnitSize\x12Q\n\x13pump_speed_settings\x18\x0e \x01(\x0b\x32\x34.device.heat_pump.config.v1.ccv.v1.PumpSpeedSettings\x12L\n\x10\x61larm_thresholds\x18\x0f \x01(\x0b\x32\x32.device.heat_pump.config.v1.ccv.v1.AlarmThresholds\x12N\n\x11\x65lectricity_meter\x18\x10 \x01(\x0b\x32\x33.device.heat_pump.config.v1.ccv.v1.ElectricityMeter\x12\x46\n\rinline_heater\x18\x11 \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.InlineHeater\x12@\n\nnight_mode\x18\x12 \x01(\x0b\x32,.device.heat_pump.config.v1.ccv.v1.NightMode\x12\x42\n\x0b\x66low_meters\x18\x13 \x01(\x0b\x32-.device.heat_pump.config.v1.ccv.v1.FlowMeters\x12Q\n\x13\x65nergy_balance_kick\x18\x14 \x01(\x0b\x32\x34.device.heat_pump.config.v1.ccv.v1.EnergyBalanceKickJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\x03\x10\x04J\x04\x08\x06\x10\x07R\x1c\x64\x65precated_ccv_serial_numberR\x16\x64\x65precated_ccv_versionR!deprecated_external_sensor_valuesR\x17\x64\x65precated_heating_mode*\x95\x01\n\x0fOutdoorUnitSize\x12!\n\x1dOUTDOOR_UNIT_SIZE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aOUTDOOR_UNIT_SIZE_AIRA_6KW\x10\x01\x12\x1e\n\x1aOUTDOOR_UNIT_SIZE_AIRA_8KW\x10\x02\x12\x1f\n\x1bOUTDOOR_UNIT_SIZE_AIRA_12KW\x10\x03\x42\xec\x01\n3com.aira.contract.device.heat_pump.config.v1.ccv.v1B\x0e\x43\x63vConfigProtoP\x01\xa2\x02\x05\x44HCVC\xaa\x02 Device.HeatPump.Config.V1.Ccv.V1\xca\x02 Device\\HeatPump\\Config\\V1\\Ccv\\V1\xe2\x02,Device\\HeatPump\\Config\\V1\\Ccv\\V1\\GPBMetadata\xea\x02%Device::HeatPump::Config::V1::Ccv::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.config.v1.ccv.v1.ccv_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3com.aira.contract.device.heat_pump.config.v1.ccv.v1B\016CcvConfigProtoP\001\242\002\005DHCVC\252\002 Device.HeatPump.Config.V1.Ccv.V1\312\002 Device\\HeatPump\\Config\\V1\\Ccv\\V1\342\002,Device\\HeatPump\\Config\\V1\\Ccv\\V1\\GPBMetadata\352\002%Device::HeatPump::Config::V1::Ccv::V1'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_speed_level']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_speed_level']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_working_mode']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_working_mode']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_compressor_limit_time']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_compressor_limit_time']._serialized_options = b'\030\001'
  _globals['_DOMESTICHOTWATERBOOST'].fields_by_name['deprecated_remaining_boost_time']._loaded_options = None
  _globals['_DOMESTICHOTWATERBOOST'].fields_by_name['deprecated_remaining_boost_time']._serialized_options = b'\030\001'
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_control_enabled']._loaded_options = None
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_control_enabled']._serialized_options = b'\030\001'
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_mixing_valve_pi_regulator']._loaded_options = None
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_mixing_valve_pi_regulator']._serialized_options = b'\030\001'
  _globals['_OUTDOORUNITSIZE']._serialized_start=9695
  _globals['_OUTDOORUNITSIZE']._serialized_end=9844
  _globals['_SENSORSOURCES']._serialized_start=142
  _globals['_SENSORSOURCES']._serialized_end=1167
  _globals['_COMPRESSORSETTINGS']._serialized_start=1170
  _globals['_COMPRESSORSETTINGS']._serialized_end=2456
  _globals['_DOMESTICHOTWATERBOOST']._serialized_start=2459
  _globals['_DOMESTICHOTWATERBOOST']._serialized_end=2632
  _globals['_PIREGULATOR']._serialized_start=2634
  _globals['_PIREGULATOR']._serialized_end=2719
  _globals['_HEATINGSYSTEM']._serialized_start=2722
  _globals['_HEATINGSYSTEM']._serialized_end=3232
  _globals['_LEGIONELLASETTINGS']._serialized_start=3235
  _globals['_LEGIONELLASETTINGS']._serialized_end=3557
  _globals['_DHWSYSTEM']._serialized_start=3560
  _globals['_DHWSYSTEM']._serialized_end=4182
  _globals['_ZONEMIXINGVALVE']._serialized_start=4185
  _globals['_ZONEMIXINGVALVE']._serialized_end=4538
  _globals['_ZONEHEATINGSETTINGS']._serialized_start=4541
  _globals['_ZONEHEATINGSETTINGS']._serialized_end=4855
  _globals['_ZONECOOLINGSETTINGS']._serialized_start=4858
  _globals['_ZONECOOLINGSETTINGS']._serialized_end=5172
  _globals['_ZONESETTINGS']._serialized_start=5175
  _globals['_ZONESETTINGS']._serialized_end=5664
  _globals['_AWAYMODE']._serialized_start=5667
  _globals['_AWAYMODE']._serialized_end=5829
  _globals['_HEATINGCOOLING']._serialized_start=5832
  _globals['_HEATINGCOOLING']._serialized_end=6652
  _globals['_PUMPSPEEDSETTINGS']._serialized_start=6655
  _globals['_PUMPSPEEDSETTINGS']._serialized_end=6876
  _globals['_ALARMTHRESHOLDS']._serialized_start=6879
  _globals['_ALARMTHRESHOLDS']._serialized_end=7078
  _globals['_ELECTRICITYMETER']._serialized_start=7081
  _globals['_ELECTRICITYMETER']._serialized_end=7353
  _globals['_ELECTRICITYMETER_ELECTRICITYMETERTYPE']._serialized_start=7190
  _globals['_ELECTRICITYMETER_ELECTRICITYMETERTYPE']._serialized_end=7353
  _globals['_INLINEHEATER']._serialized_start=7356
  _globals['_INLINEHEATER']._serialized_end=7776
  _globals['_INLINEHEATER_INLINEHEATERUSAGE']._serialized_start=7622
  _globals['_INLINEHEATER_INLINEHEATERUSAGE']._serialized_end=7776
  _globals['_NIGHTMODE']._serialized_start=7778
  _globals['_NIGHTMODE']._serialized_end=7823
  _globals['_FLOWMETERS']._serialized_start=7826
  _globals['_FLOWMETERS']._serialized_end=8283
  _globals['_FLOWMETERS_FLOWMETERTYPE']._serialized_start=8007
  _globals['_FLOWMETERS_FLOWMETERTYPE']._serialized_end=8283
  _globals['_ENERGYBALANCEKICK']._serialized_start=8286
  _globals['_ENERGYBALANCEKICK']._serialized_end=8481
  _globals['_CCVCONFIG']._serialized_start=8484
  _globals['_CCVCONFIG']._serialized_end=9692
# @@protoc_insertion_point(module_scope)