# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: notification/v2/notification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'notification/v2/notification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...util.v2 import uuid_pb2 as util_dot_v2_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"notification/v2/notification.proto\x12\x0fnotification.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12util/v2/uuid.proto\"\xac\x03\n\x0cNotification\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04read\x18\x05 \x01(\x08\x12<\n\x11notification_type\x18\x06 \x01(\x0e\x32!.notification.v2.NotificationType\x12)\n\x07subject\x18\x07 \x01(\x0e\x32\x18.notification.v2.Subject\x12:\n\x07\x63ontent\x18\x08 \x01(\x0b\x32$.notification.v2.NotificationContentH\x00\x88\x01\x01\x12\x38\n\x06\x61\x63tion\x18\t \x01(\x0b\x32#.notification.v2.NotificationActionH\x01\x88\x01\x01\x12\x1c\n\x0fmin_app_version\x18\n \x01(\tH\x02\x88\x01\x01\x42\n\n\x08_contentB\t\n\x07_actionB\x12\n\x10_min_app_version\"A\n\x15\x43ommunicationChannels\x12\x0b\n\x03sms\x18\x01 \x01(\x08\x12\x0c\n\x04push\x18\x02 \x01(\x08\x12\r\n\x05\x65mail\x18\x03 \x01(\x08\"2\n\x13NotificationContent\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\"i\n\x12NotificationAction\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.notification.v2.NotificationActionType\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t*i\n\x07Subject\x12\x17\n\x13SUBJECT_UNSPECIFIED\x10\x00\x12\x15\n\x11SUBJECT_HEAT_PUMP\x10\x01\x12\x16\n\x12SUBJECT_INVITATION\x10\x02\x12\x16\n\x12SUBJECT_THERMOSTAT\x10\x03*\x8d\x01\n\x10NotificationType\x12!\n\x1dNOTIFICATION_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16NOTIFICATION_TYPE_INFO\x10\x01\x12\x1b\n\x17NOTIFICATION_TYPE_ERROR\x10\x02\x12\x1d\n\x19NOTIFICATION_TYPE_WARNING\x10\x03*\x88\x01\n\x16NotificationActionType\x12(\n$NOTIFICATION_ACTION_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cNOTIFICATION_ACTION_TYPE_URL\x10\x01\x12\"\n\x1eNOTIFICATION_ACTION_TYPE_ROUTE\x10\x02\x42\x93\x01\n!com.aira.contract.notification.v2B\x11NotificationProtoP\x01\xa2\x02\x03NXX\xaa\x02\x0fNotification.V2\xca\x02\x0fNotification\\V2\xe2\x02\x1bNotification\\V2\\GPBMetadata\xea\x02\x10Notification::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification.v2.notification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.notification.v2B\021NotificationProtoP\001\242\002\003NXX\252\002\017Notification.V2\312\002\017Notification\\V2\342\002\033Notification\\V2\\GPBMetadata\352\002\020Notification::V2'
  _globals['_SUBJECT']._serialized_start=765
  _globals['_SUBJECT']._serialized_end=870
  _globals['_NOTIFICATIONTYPE']._serialized_start=873
  _globals['_NOTIFICATIONTYPE']._serialized_end=1014
  _globals['_NOTIFICATIONACTIONTYPE']._serialized_start=1017
  _globals['_NOTIFICATIONACTIONTYPE']._serialized_end=1153
  _globals['_NOTIFICATION']._serialized_start=109
  _globals['_NOTIFICATION']._serialized_end=537
  _globals['_COMMUNICATIONCHANNELS']._serialized_start=539
  _globals['_COMMUNICATIONCHANNELS']._serialized_end=604
  _globals['_NOTIFICATIONCONTENT']._serialized_start=606
  _globals['_NOTIFICATIONCONTENT']._serialized_end=656
  _globals['_NOTIFICATIONACTION']._serialized_start=658
  _globals['_NOTIFICATIONACTION']._serialized_end=763
# @@protoc_insertion_point(module_scope)