# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/modbus/v1/exception.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/modbus/v1/exception.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*device/heat_pump/modbus/v1/exception.proto\x12\x1a\x64\x65vice.heat_pump.modbus.v1*\xde\x02\n\tException\x12\x19\n\x15\x45XCEPTION_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x45XCEPTION_ILLEGAL_FUNCTION\x10\x01\x12\"\n\x1e\x45XCEPTION_ILLEGAL_DATA_ADDRESS\x10\x02\x12 \n\x1c\x45XCEPTION_ILLEGAL_DATA_VALUE\x10\x03\x12#\n\x1f\x45XCEPTION_SERVER_DEVICE_FAILURE\x10\x04\x12\x19\n\x15\x45XCEPTION_ACKNOWLEDGE\x10\x05\x12 \n\x1c\x45XCEPTION_SERVER_DEVICE_BUSY\x10\x06\x12!\n\x1d\x45XCEPTION_MEMORY_PARITY_ERROR\x10\x08\x12&\n\"EXCEPTION_GATEWAY_PATH_UNAVAILABLE\x10\n\x12#\n\x1f\x45XCEPTION_GATEWAY_TARGET_DEVICE\x10\x0b\x42\xc5\x01\n,com.aira.contract.device.heat_pump.modbus.v1B\x0e\x45xceptionProtoP\x01\xa2\x02\x03\x44HM\xaa\x02\x19\x44\x65vice.HeatPump.Modbus.V1\xca\x02\x19\x44\x65vice\\HeatPump\\Modbus\\V1\xe2\x02%Device\\HeatPump\\Modbus\\V1\\GPBMetadata\xea\x02\x1c\x44\x65vice::HeatPump::Modbus::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.modbus.v1.exception_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,com.aira.contract.device.heat_pump.modbus.v1B\016ExceptionProtoP\001\242\002\003DHM\252\002\031Device.HeatPump.Modbus.V1\312\002\031Device\\HeatPump\\Modbus\\V1\342\002%Device\\HeatPump\\Modbus\\V1\\GPBMetadata\352\002\034Device::HeatPump::Modbus::V1'
  _globals['_EXCEPTION']._serialized_start=75
  _globals['_EXCEPTION']._serialized_end=425
# @@protoc_insertion_point(module_scope)