# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: notification/v1/notification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'notification/v1/notification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"notification/v1/notification.proto\x12\x0fnotification.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12util/v1/uuid.proto\"\xfb\x01\n\x0cNotification\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.UuidB\x02\x18\x01\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04read\x18\x05 \x01(\x08\x12<\n\x11notification_type\x18\x06 \x01(\x0e\x32!.notification.v1.NotificationType\x12)\n\x07subject\x18\x07 \x01(\x0e\x32\x18.notification.v1.Subject:\x02\x18\x01J\x04\x08\x08\x10\t\"<\n\x15\x43ommunicationChannels\x12\x0b\n\x03sms\x18\x02 \x01(\x08\x12\x0c\n\x04push\x18\x03 \x01(\x08:\x02\x18\x01J\x04\x08\x01\x10\x02*=\n\x07Subject\x12\x17\n\x13SUBJECT_UNSPECIFIED\x10\x00\x12\x15\n\x11SUBJECT_HEAT_PUMP\x10\x01\x1a\x02\x18\x01*x\n\x10NotificationType\x12!\n\x1dNOTIFICATION_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16NOTIFICATION_TYPE_INFO\x10\x01\x12\x1b\n\x17NOTIFICATION_TYPE_ERROR\x10\x02\x1a\x02\x18\x01\"\x04\x08\x03\x10\x03\x42\x93\x01\n!com.aira.contract.notification.v1B\x11NotificationProtoP\x01\xa2\x02\x03NXX\xaa\x02\x0fNotification.V1\xca\x02\x0fNotification\\V1\xe2\x02\x1bNotification\\V1\\GPBMetadata\xea\x02\x10Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification.v1.notification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.notification.v1B\021NotificationProtoP\001\242\002\003NXX\252\002\017Notification.V1\312\002\017Notification\\V1\342\002\033Notification\\V1\\GPBMetadata\352\002\020Notification::V1'
  _globals['_SUBJECT']._loaded_options = None
  _globals['_SUBJECT']._serialized_options = b'\030\001'
  _globals['_NOTIFICATIONTYPE']._loaded_options = None
  _globals['_NOTIFICATIONTYPE']._serialized_options = b'\030\001'
  _globals['_NOTIFICATION'].fields_by_name['id']._loaded_options = None
  _globals['_NOTIFICATION'].fields_by_name['id']._serialized_options = b'\030\001'
  _globals['_NOTIFICATION']._loaded_options = None
  _globals['_NOTIFICATION']._serialized_options = b'\030\001'
  _globals['_COMMUNICATIONCHANNELS']._loaded_options = None
  _globals['_COMMUNICATIONCHANNELS']._serialized_options = b'\030\001'
  _globals['_SUBJECT']._serialized_start=424
  _globals['_SUBJECT']._serialized_end=485
  _globals['_NOTIFICATIONTYPE']._serialized_start=487
  _globals['_NOTIFICATIONTYPE']._serialized_end=607
  _globals['_NOTIFICATION']._serialized_start=109
  _globals['_NOTIFICATION']._serialized_end=360
  _globals['_COMMUNICATIONCHANNELS']._serialized_start=362
  _globals['_COMMUNICATIONCHANNELS']._serialized_end=422
# @@protoc_insertion_point(module_scope)