# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/v1/devices.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/v1/devices.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..heat_pump.state.v1 import state_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_state__pb2
from ..heat_pump.util.v1 import water_tank_size_pb2 as device_dot_heat__pump_dot_util_dot_v1_dot_water__tank__size__pb2
from . import certificate_pb2 as device_dot_v1_dot_certificate__pb2
from . import online_pb2 as device_dot_v1_dot_online__pb2
from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x64\x65vice/v1/devices.proto\x12\tdevice.v1\x1a%device/heat_pump/state/v1/state.proto\x1a.device/heat_pump/util/v1/water_tank_size.proto\x1a\x1b\x64\x65vice/v1/certificate.proto\x1a\x16\x64\x65vice/v1/online.proto\x1a\x12util/v1/uuid.proto\"\xa9\x02\n\x08HeatPump\x12+\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32\x16.device.v1.Certificate\x12\x19\n\x02id\x18\x03 \x01(\x0b\x32\r.util.v1.Uuid\x12\x35\n\x14\x64\x65precated_tank_size\x18\x04 \x01(\x0e\x32\x13.device.v1.TankSizeB\x02\x18\x01\x12:\n\ttank_size\x18\x08 \x01(\x0e\x32\'.device.heat_pump.util.v1.WaterTankSize\x12\x1a\n\x12night_mode_enabled\x18\x07 \x01(\x08J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x02\x10\x03R\x13heating_zone_1_nameR\x13heating_zone_2_nameR\nthread_key\"X\n\x06\x44\x65vice\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12!\n\x06online\x18\x04 \x01(\x0b\x32\x11.device.v1.OnlineJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x05\x10\x06\"=\n\x11GetDevicesRequest\x12(\n\rheat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v1.UuidB\x02\x18\x01\"8\n\x12GetDevicesResponse\x12\"\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x11.device.v1.Device\"4\n\x17GetDeviceDetailsRequest\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"L\n\x18GetDeviceDetailsResponse\x12(\n\theat_pump\x18\x01 \x01(\x0b\x32\x13.device.v1.HeatPumpH\x00\x42\x06\n\x04type\"N\n\x1a\x43reateDeviceDetailsRequest\x12(\n\theat_pump\x18\x01 \x01(\x0b\x32\x13.device.v1.HeatPumpH\x00\x42\x06\n\x04type\"\x1d\n\x1b\x43reateDeviceDetailsResponse\"\x16\n\x14StreamDevicesRequest\";\n\x15StreamDevicesResponse\x12\"\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x11.device.v1.Device\"8\n\x10GetStatesRequest\x12$\n\rheat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v1.Uuid\"O\n\x11GetStatesResponse\x12:\n\x10heat_pump_states\x18\x01 \x03(\x0b\x32 .device.heat_pump.state.v1.State\";\n\x13StreamStatesRequest\x12$\n\rheat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v1.Uuid\"R\n\x14StreamStatesResponse\x12:\n\x10heat_pump_states\x18\x01 \x03(\x0b\x32 .device.heat_pump.state.v1.State*Y\n\x08TankSize\x12\x19\n\x15TANK_SIZE_UNSPECIFIED\x10\x00\x12\x18\n\x14TANK_SIZE_100_LITERS\x10\x01\x12\x18\n\x14TANK_SIZE_250_LITERS\x10\x02\x32\x8f\x04\n\x0e\x44\x65vicesService\x12I\n\nGetDevices\x12\x1c.device.v1.GetDevicesRequest\x1a\x1d.device.v1.GetDevicesResponse\x12[\n\x10GetDeviceDetails\x12\".device.v1.GetDeviceDetailsRequest\x1a#.device.v1.GetDeviceDetailsResponse\x12\x64\n\x13\x43reateDeviceDetails\x12%.device.v1.CreateDeviceDetailsRequest\x1a&.device.v1.CreateDeviceDetailsResponse\x12T\n\rStreamDevices\x12\x1f.device.v1.StreamDevicesRequest\x1a .device.v1.StreamDevicesResponse0\x01\x12\x46\n\tGetStates\x12\x1b.device.v1.GetStatesRequest\x1a\x1c.device.v1.GetStatesResponse\x12Q\n\x0cStreamStates\x12\x1e.device.v1.StreamStatesRequest\x1a\x1f.device.v1.StreamStatesResponse0\x01\x42p\n\x1b\x63om.aira.contract.device.v1B\x0c\x44\x65vicesProtoP\x01\xa2\x02\x03\x44XX\xaa\x02\tDevice.V1\xca\x02\tDevice\\V1\xe2\x02\x15\x44\x65vice\\V1\\GPBMetadata\xea\x02\nDevice::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.v1.devices_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.aira.contract.device.v1B\014DevicesProtoP\001\242\002\003DXX\252\002\tDevice.V1\312\002\tDevice\\V1\342\002\025Device\\V1\\GPBMetadata\352\002\nDevice::V1'
  _globals['_HEATPUMP'].fields_by_name['deprecated_tank_size']._loaded_options = None
  _globals['_HEATPUMP'].fields_by_name['deprecated_tank_size']._serialized_options = b'\030\001'
  _globals['_GETDEVICESREQUEST'].fields_by_name['heat_pump_ids']._loaded_options = None
  _globals['_GETDEVICESREQUEST'].fields_by_name['heat_pump_ids']._serialized_options = b'\030\001'
  _globals['_TANKSIZE']._serialized_start=1321
  _globals['_TANKSIZE']._serialized_end=1410
  _globals['_HEATPUMP']._serialized_start=199
  _globals['_HEATPUMP']._serialized_end=496
  _globals['_DEVICE']._serialized_start=498
  _globals['_DEVICE']._serialized_end=586
  _globals['_GETDEVICESREQUEST']._serialized_start=588
  _globals['_GETDEVICESREQUEST']._serialized_end=649
  _globals['_GETDEVICESRESPONSE']._serialized_start=651
  _globals['_GETDEVICESRESPONSE']._serialized_end=707
  _globals['_GETDEVICEDETAILSREQUEST']._serialized_start=709
  _globals['_GETDEVICEDETAILSREQUEST']._serialized_end=761
  _globals['_GETDEVICEDETAILSRESPONSE']._serialized_start=763
  _globals['_GETDEVICEDETAILSRESPONSE']._serialized_end=839
  _globals['_CREATEDEVICEDETAILSREQUEST']._serialized_start=841
  _globals['_CREATEDEVICEDETAILSREQUEST']._serialized_end=919
  _globals['_CREATEDEVICEDETAILSRESPONSE']._serialized_start=921
  _globals['_CREATEDEVICEDETAILSRESPONSE']._serialized_end=950
  _globals['_STREAMDEVICESREQUEST']._serialized_start=952
  _globals['_STREAMDEVICESREQUEST']._serialized_end=974
  _globals['_STREAMDEVICESRESPONSE']._serialized_start=976
  _globals['_STREAMDEVICESRESPONSE']._serialized_end=1035
  _globals['_GETSTATESREQUEST']._serialized_start=1037
  _globals['_GETSTATESREQUEST']._serialized_end=1093
  _globals['_GETSTATESRESPONSE']._serialized_start=1095
  _globals['_GETSTATESRESPONSE']._serialized_end=1174
  _globals['_STREAMSTATESREQUEST']._serialized_start=1176
  _globals['_STREAMSTATESREQUEST']._serialized_end=1235
  _globals['_STREAMSTATESRESPONSE']._serialized_start=1237
  _globals['_STREAMSTATESRESPONSE']._serialized_end=1319
  _globals['_DEVICESSERVICE']._serialized_start=1413
  _globals['_DEVICESSERVICE']._serialized_end=1940
# @@protoc_insertion_point(module_scope)