# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user_account/v2/user_account.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'user_account/v2/user_account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...notification.v2 import notification_pb2 as notification_dot_v2_dot_notification__pb2
from . import role_pb2 as user__account_dot_v2_dot_role__pb2
from ...util.v2 import locale_pb2 as util_dot_v2_dot_locale__pb2
from ...util.v2 import market_pb2 as util_dot_v2_dot_market__pb2
from ...util.v2 import uuid_pb2 as util_dot_v2_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"user_account/v2/user_account.proto\x12\x0fuser_account.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"notification/v2/notification.proto\x1a\x1auser_account/v2/role.proto\x1a\x14util/v2/locale.proto\x1a\x14util/v2/market.proto\x1a\x12util/v2/uuid.proto\"B\n\x1bGetHeatPumpZoneNamesRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"N\n\x1cGetHeatPumpZoneNamesResponse\x12.\n\nzone_names\x18\x01 \x01(\x0b\x32\x1a.user_account.v2.ZoneNames\"+\n\tZoneNames\x12\x0e\n\x06zone_1\x18\x01 \x01(\t\x12\x0e\n\x06zone_2\x18\x02 \x01(\t\"\x90\x01\n\x19\x43onfirmEmailChangeRequest\x12#\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.UuidH\x00\x88\x01\x01\x12\x11\n\tnew_email\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x04 \x01(\tB\n\n\x08_user_id\"\x1c\n\x1a\x43onfirmEmailChangeResponse\"\x82\x01\n\x19\x43onfirmPhoneNumberRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x04 \x01(\t\"\x1c\n\x1a\x43onfirmPhoneNumberResponse\"D\n!GetFeaturesAsNotificationsRequest\x12\x1f\n\x06locale\x18\x01 \x01(\x0e\x32\x0f.util.v2.Locale\"Z\n\"GetFeaturesAsNotificationsResponse\x12\x34\n\rnotifications\x18\x01 \x03(\x0b\x32\x1d.notification.v2.Notification\"k\n\x12HeatPumpPermission\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x30\n\x0bpermissions\x18\x02 \x03(\x0e\x32\x1b.user_account.v2.Permission\"\x83\x01\n\x1d\x41\x64\x64HeatPumpPermissionsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x42\n\x15heat_pump_permissions\x18\x02 \x03(\x0b\x32#.user_account.v2.HeatPumpPermission\" \n\x1e\x41\x64\x64HeatPumpPermissionsResponse\"\x9c\x03\n\x0bUserAccount\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12!\n\ncontact_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x08 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\t \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\n \x01(\x08\x12!\n\ncognito_id\x18\x0b \x01(\x0b\x32\r.util.v2.Uuid\x12\x1e\n\x16phone_number_confirmed\x18\x0c \x01(\x08\x12S\n\x1dproximity_verification_status\x18\r \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatusJ\x04\x08\x07\x10\x08\"\x84\x02\n\x10InstallerAccount\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12!\n\ncognito_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x08 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\t \x01(\x0e\x32\x0f.util.v2.Market\x12\x1d\n\x15is_external_installer\x18\n \x01(\x08\"E\n GetUserAccountByCognitoIdRequest\x12!\n\ncognito_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\x8d\x01\n!GetUserAccountByCognitoIdResponse\x12\x32\n\x0cuser_account\x18\x02 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\x12.\n\nhouseholds\x18\x03 \x03(\x0b\x32\x1a.user_account.v2.HouseholdJ\x04\x08\x01\x10\x02\"?\n\x1dGetUserAccountByUserIdRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"T\n\x1eGetUserAccountByUserIdResponse\x12\x32\n\x0cuser_account\x18\x01 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\"E\n GetUserAccountByContactIdRequest\x12!\n\ncontact_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"]\n!GetUserAccountByContactIdResponse\x12\x32\n\x0cuser_account\x18\x02 \x01(\x0b\x32\x1c.user_account.v2.UserAccountJ\x04\x08\x01\x10\x02\"\x8e\x02\n\x18\x43reateUserAccountRequest\x12!\n\ncontact_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x14\n\x0cphone_number\x18\x03 \x01(\t\x12\x12\n\ngiven_name\x18\x04 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x05 \x01(\t\x12\x1f\n\x06locale\x18\x06 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x07 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\x08 \x01(\x08\x12!\n\ncognito_id\x18\t \x01(\x0b\x32\r.util.v2.Uuid\"O\n\x19\x43reateUserAccountResponse\x12\x32\n\x0cuser_account\x18\x01 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\"\x82\x02\n\x18UpdateUserAccountRequest\x12\x1e\n\x07user_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12!\n\ncontact_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x07 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x08 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\t \x01(\x08J\x04\x08\x01\x10\x02\"O\n\x19UpdateUserAccountResponse\x12\x32\n\x0cuser_account\x18\x01 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\"\xc3\x01\n\rLegalDocument\x12\"\n\x0b\x64ocument_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x39\n\rdocument_type\x18\x03 \x01(\x0e\x32\".user_account.v2.LegalDocumentType\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x1f\n\x06market\x18\x05 \x01(\x0e\x32\x0f.util.v2.Market\x12\x10\n\x08web_link\x18\x06 \x01(\t\"\xa5\x01\n\x1aLegalDocumentUserAgreement\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12/\n\x0b\x61\x63\x63\x65pted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x0elegal_document\x18\x03 \x01(\x0b\x32\x1e.user_account.v2.LegalDocument\"=\n\x1bGetAllUserAgreementsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"_\n\x1cGetAllUserAgreementsResponse\x12?\n\nagreements\x18\x01 \x03(\x0b\x32+.user_account.v2.LegalDocumentUserAgreement\"s\n\'CreateLegalDocumentUserAgreementRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12(\n\x11legal_document_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\"*\n(CreateLegalDocumentUserAgreementResponse\"L\n*UserHasAcceptedLatestLegalDocumentsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"n\n+UserHasAcceptedLatestLegalDocumentsResponse\x12?\n\nagreements\x18\x01 \x03(\x0b\x32+.user_account.v2.LegalDocumentUserAgreement\"b\n LegalDocumentUserAgreementEntity\x12>\n\tagreement\x18\x01 \x01(\x0b\x32+.user_account.v2.LegalDocumentUserAgreement\"\xd7\x03\n\x16\x41\x64minUpdateUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x12\n\x05\x65mail\x18\x02 \x01(\tH\x00\x88\x01\x01\x12#\n\x0cheat_pump_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x19\n\x0cphone_number\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x17\n\ngiven_name\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x66\x61mily_name\x18\x06 \x01(\tH\x03\x88\x01\x01\x12$\n\x06locale\x18\x07 \x01(\x0e\x32\x0f.util.v2.LocaleH\x04\x88\x01\x01\x12$\n\x06market\x18\x08 \x01(\x0e\x32\x0f.util.v2.MarketH\x05\x88\x01\x01\x12N\n\x13verification_status\x18\n \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatusH\x06\x88\x01\x01\x42\x08\n\x06_emailB\x0f\n\r_phone_numberB\r\n\x0b_given_nameB\x0e\n\x0c_family_nameB\t\n\x07_localeB\t\n\x07_marketB\x16\n\x14_verification_statusJ\x04\x08\t\x10\nR\x0cis_installer\"\x19\n\x17\x41\x64minUpdateUserResponse\"\x81\x02\n\x16\x41\x64minCreateUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12#\n\x0cheat_pump_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x07 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x08 \x01(\x0e\x32\x0f.util.v2.MarketJ\x04\x08\t\x10\nR\x0cis_installer\"\x19\n\x17\x41\x64minCreateUserResponse\"\xd3\x01\n\"AdminCreateInstallerAccountRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x14\n\x0cphone_number\x18\x02 \x01(\t\x12\x12\n\ngiven_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x1f\n\x06locale\x18\x05 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x06 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1d\n\x15is_external_installer\x18\x07 \x01(\x08\"c\n#AdminCreateInstallerAccountResponse\x12<\n\x11installer_account\x18\x01 \x01(\x0b\x32!.user_account.v2.InstallerAccount\"\xe4\x01\n\"AdminUpdateInstallerAccountRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x02 \x01(\t\x12\x12\n\ngiven_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x1f\n\x06locale\x18\x05 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x06 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1d\n\x15is_external_installer\x18\x07 \x01(\x08\"c\n#AdminUpdateInstallerAccountResponse\x12<\n\x11installer_account\x18\x01 \x01(\x0b\x32!.user_account.v2.InstallerAccount\"T\n AdminFindInstallerAccountRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12!\n\ncognito_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\"a\n!AdminFindInstallerAccountResponse\x12<\n\x11installer_account\x18\x01 \x01(\x0b\x32!.user_account.v2.InstallerAccount\"I\n\"GetUserAccountsByHeatPumpIdRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"Y\n#GetUserAccountsByHeatPumpIdResponse\x12\x32\n\x0cuser_account\x18\x01 \x03(\x0b\x32\x1c.user_account.v2.UserAccount\"M\n\x1cGetHouseholdsByUserIdRequest\x12)\n\x12\x65ngagement_user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid:\x02\x18\x01\"S\n\x1dGetHouseholdsByUserIdResponse\x12.\n\nhouseholds\x18\x01 \x03(\x0b\x32\x1a.user_account.v2.Household:\x02\x18\x01\"\xb8\x01\n\tHousehold\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\tresidents\x18\x03 \x03(\x0b\x32\x19.user_account.v2.Resident\x12,\n\theat_pump\x18\x04 \x01(\x0b\x32\x19.user_account.v2.HeatPump\x12\"\n\x0b\x66\x61\x63ility_id\x18\x05 \x01(\x0b\x32\r.util.v2.Uuid:\x02\x18\x01\")\n\x08HeatPump\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid:\x02\x18\x01\"\xbb\x01\n\x08Resident\x12)\n\x12\x65ngagement_user_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12#\n\x0chousehold_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x12\n\ngiven_name\x18\x04 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12#\n\x04role\x18\x07 \x01(\x0e\x32\x15.user_account.v2.Role:\x02\x18\x01\"\xa1\x01\n\x15\x44\x65leteResidentRequest\x12)\n\x12\x65ngagement_user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12#\n\x0chousehold_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12\x34\n\x1d\x64\x65leted_by_engagement_user_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid:\x02\x18\x01\"\x1c\n\x16\x44\x65leteResidentResponse:\x02\x18\x01\"\'\n%GetProximityVerificationStatusRequest\"s\n&GetProximityVerificationStatusResponse\x12I\n\x13verification_status\x18\x01 \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatus\"D\n\x16VerifyProximityRequest\x12*\n\x13\x63lose_heat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v2.Uuid\":\n\x17VerifyProximityResponse\x12\x1f\n\x17verification_successful\x18\x01 \x01(\x08*\x84\x01\n\nPermission\x12\x1a\n\x16PERMISSION_UNSPECIFIED\x10\x00\x12\x13\n\x0fPERMISSION_READ\x10\x01\x12\x16\n\x12PERMISSION_CONTROL\x10\x02\x12\x17\n\x13PERMISSION_SCHEDULE\x10\x03\x12\x14\n\x10PERMISSION_SHARE\x10\x04*\x8a\x01\n\x11LegalDocumentType\x12#\n\x1fLEGAL_DOCUMENT_TYPE_UNSPECIFIED\x10\x00\x12(\n$LEGAL_DOCUMENT_TYPE_TERMS_OF_SERVICE\x10\x01\x12&\n\"LEGAL_DOCUMENT_TYPE_PRIVACY_POLICY\x10\x02*\xd6\x01\n\x1bProximityVerificationStatus\x12-\n)PROXIMITY_VERIFICATION_STATUS_UNSPECIFIED\x10\x00\x12.\n*PROXIMITY_VERIFICATION_STATUS_NOT_VERIFIED\x10\x01\x12*\n&PROXIMITY_VERIFICATION_STATUS_VERIFIED\x10\x02\x12,\n(PROXIMITY_VERIFICATION_STATUS_NOT_NEEDED\x10\x03\x32\xe4\x15\n\x12UserAccountService\x12y\n\x16\x41\x64\x64HeatPumpPermissions\x12..user_account.v2.AddHeatPumpPermissionsRequest\x1a/.user_account.v2.AddHeatPumpPermissionsResponse\x12m\n\x12\x43onfirmEmailChange\x12*.user_account.v2.ConfirmEmailChangeRequest\x1a+.user_account.v2.ConfirmEmailChangeResponse\x12m\n\x12\x43onfirmPhoneNumber\x12*.user_account.v2.ConfirmPhoneNumberRequest\x1a+.user_account.v2.ConfirmPhoneNumberResponse\x12\x82\x01\n\x19GetUserAccountByContactId\x12\x31.user_account.v2.GetUserAccountByContactIdRequest\x1a\x32.user_account.v2.GetUserAccountByContactIdResponse\x12\x82\x01\n\x19GetUserAccountByCognitoId\x12\x31.user_account.v2.GetUserAccountByCognitoIdRequest\x1a\x32.user_account.v2.GetUserAccountByCognitoIdResponse\x12y\n\x16GetUserAccountByUserId\x12..user_account.v2.GetUserAccountByUserIdRequest\x1a/.user_account.v2.GetUserAccountByUserIdResponse\x12j\n\x11\x43reateUserAccount\x12).user_account.v2.CreateUserAccountRequest\x1a*.user_account.v2.CreateUserAccountResponse\x12j\n\x11UpdateUserAccount\x12).user_account.v2.UpdateUserAccountRequest\x1a*.user_account.v2.UpdateUserAccountResponse\x12\x64\n\x0f\x41\x64minUpdateUser\x12\'.user_account.v2.AdminUpdateUserRequest\x1a(.user_account.v2.AdminUpdateUserResponse\x12\x88\x01\n\x1b\x41\x64minCreateInstallerAccount\x12\x33.user_account.v2.AdminCreateInstallerAccountRequest\x1a\x34.user_account.v2.AdminCreateInstallerAccountResponse\x12\x82\x01\n\x19\x41\x64minFindInstallerAccount\x12\x31.user_account.v2.AdminFindInstallerAccountRequest\x1a\x32.user_account.v2.AdminFindInstallerAccountResponse\x12\x88\x01\n\x1b\x41\x64minUpdateInstallerAccount\x12\x33.user_account.v2.AdminUpdateInstallerAccountRequest\x1a\x34.user_account.v2.AdminUpdateInstallerAccountResponse\x12s\n\x14GetAllUserAgreements\x12,.user_account.v2.GetAllUserAgreementsRequest\x1a-.user_account.v2.GetAllUserAgreementsResponse\x12\x97\x01\n CreateLegalDocumentUserAgreement\x12\x38.user_account.v2.CreateLegalDocumentUserAgreementRequest\x1a\x39.user_account.v2.CreateLegalDocumentUserAgreementResponse\x12\xa0\x01\n#UserHasAcceptedLatestLegalDocuments\x12;.user_account.v2.UserHasAcceptedLatestLegalDocumentsRequest\x1a<.user_account.v2.UserHasAcceptedLatestLegalDocumentsResponse\x12s\n\x14GetHeatPumpZoneNames\x12,.user_account.v2.GetHeatPumpZoneNamesRequest\x1a-.user_account.v2.GetHeatPumpZoneNamesResponse\x12\x88\x01\n\x1bGetUserAccountsByHeatPumpId\x12\x33.user_account.v2.GetUserAccountsByHeatPumpIdRequest\x1a\x34.user_account.v2.GetUserAccountsByHeatPumpIdResponse\x12{\n\x15GetHouseholdsByUserId\x12-.user_account.v2.GetHouseholdsByUserIdRequest\x1a..user_account.v2.GetHouseholdsByUserIdResponse\"\x03\x88\x02\x01\x12\x66\n\x0e\x44\x65leteResident\x12&.user_account.v2.DeleteResidentRequest\x1a\'.user_account.v2.DeleteResidentResponse\"\x03\x88\x02\x01\x12\x85\x01\n\x1aGetFeaturesAsNotifications\x12\x32.user_account.v2.GetFeaturesAsNotificationsRequest\x1a\x33.user_account.v2.GetFeaturesAsNotificationsResponse\x12\x91\x01\n\x1eGetProximityVerificationStatus\x12\x36.user_account.v2.GetProximityVerificationStatusRequest\x1a\x37.user_account.v2.GetProximityVerificationStatusResponse\x12\x64\n\x0fVerifyProximity\x12\'.user_account.v2.VerifyProximityRequest\x1a(.user_account.v2.VerifyProximityResponseB\x8e\x01\n!com.aira.contract.user_account.v2B\x10UserAccountProtoP\x01\xa2\x02\x03UXX\xaa\x02\x0eUserAccount.V2\xca\x02\x0eUserAccount\\V2\xe2\x02\x1aUserAccount\\V2\\GPBMetadata\xea\x02\x0fUserAccount::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_account.v2.user_account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.user_account.v2B\020UserAccountProtoP\001\242\002\003UXX\252\002\016UserAccount.V2\312\002\016UserAccount\\V2\342\002\032UserAccount\\V2\\GPBMetadata\352\002\017UserAccount::V2'
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._loaded_options = None
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_options = b'\030\001'
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._loaded_options = None
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_options = b'\030\001'
  _globals['_HOUSEHOLD']._loaded_options = None
  _globals['_HOUSEHOLD']._serialized_options = b'\030\001'
  _globals['_HEATPUMP']._loaded_options = None
  _globals['_HEATPUMP']._serialized_options = b'\030\001'
  _globals['_RESIDENT']._loaded_options = None
  _globals['_RESIDENT']._serialized_options = b'\030\001'
  _globals['_DELETERESIDENTREQUEST']._loaded_options = None
  _globals['_DELETERESIDENTREQUEST']._serialized_options = b'\030\001'
  _globals['_DELETERESIDENTRESPONSE']._loaded_options = None
  _globals['_DELETERESIDENTRESPONSE']._serialized_options = b'\030\001'
  _globals['_USERACCOUNTSERVICE'].methods_by_name['GetHouseholdsByUserId']._loaded_options = None
  _globals['_USERACCOUNTSERVICE'].methods_by_name['GetHouseholdsByUserId']._serialized_options = b'\210\002\001'
  _globals['_USERACCOUNTSERVICE'].methods_by_name['DeleteResident']._loaded_options = None
  _globals['_USERACCOUNTSERVICE'].methods_by_name['DeleteResident']._serialized_options = b'\210\002\001'
  _globals['_PERMISSION']._serialized_start=6924
  _globals['_PERMISSION']._serialized_end=7056
  _globals['_LEGALDOCUMENTTYPE']._serialized_start=7059
  _globals['_LEGALDOCUMENTTYPE']._serialized_end=7197
  _globals['_PROXIMITYVERIFICATIONSTATUS']._serialized_start=7200
  _globals['_PROXIMITYVERIFICATIONSTATUS']._serialized_end=7414
  _globals['_GETHEATPUMPZONENAMESREQUEST']._serialized_start=216
  _globals['_GETHEATPUMPZONENAMESREQUEST']._serialized_end=282
  _globals['_GETHEATPUMPZONENAMESRESPONSE']._serialized_start=284
  _globals['_GETHEATPUMPZONENAMESRESPONSE']._serialized_end=362
  _globals['_ZONENAMES']._serialized_start=364
  _globals['_ZONENAMES']._serialized_end=407
  _globals['_CONFIRMEMAILCHANGEREQUEST']._serialized_start=410
  _globals['_CONFIRMEMAILCHANGEREQUEST']._serialized_end=554
  _globals['_CONFIRMEMAILCHANGERESPONSE']._serialized_start=556
  _globals['_CONFIRMEMAILCHANGERESPONSE']._serialized_end=584
  _globals['_CONFIRMPHONENUMBERREQUEST']._serialized_start=587
  _globals['_CONFIRMPHONENUMBERREQUEST']._serialized_end=717
  _globals['_CONFIRMPHONENUMBERRESPONSE']._serialized_start=719
  _globals['_CONFIRMPHONENUMBERRESPONSE']._serialized_end=747
  _globals['_GETFEATURESASNOTIFICATIONSREQUEST']._serialized_start=749
  _globals['_GETFEATURESASNOTIFICATIONSREQUEST']._serialized_end=817
  _globals['_GETFEATURESASNOTIFICATIONSRESPONSE']._serialized_start=819
  _globals['_GETFEATURESASNOTIFICATIONSRESPONSE']._serialized_end=909
  _globals['_HEATPUMPPERMISSION']._serialized_start=911
  _globals['_HEATPUMPPERMISSION']._serialized_end=1018
  _globals['_ADDHEATPUMPPERMISSIONSREQUEST']._serialized_start=1021
  _globals['_ADDHEATPUMPPERMISSIONSREQUEST']._serialized_end=1152
  _globals['_ADDHEATPUMPPERMISSIONSRESPONSE']._serialized_start=1154
  _globals['_ADDHEATPUMPPERMISSIONSRESPONSE']._serialized_end=1186
  _globals['_USERACCOUNT']._serialized_start=1189
  _globals['_USERACCOUNT']._serialized_end=1601
  _globals['_INSTALLERACCOUNT']._serialized_start=1604
  _globals['_INSTALLERACCOUNT']._serialized_end=1864
  _globals['_GETUSERACCOUNTBYCOGNITOIDREQUEST']._serialized_start=1866
  _globals['_GETUSERACCOUNTBYCOGNITOIDREQUEST']._serialized_end=1935
  _globals['_GETUSERACCOUNTBYCOGNITOIDRESPONSE']._serialized_start=1938
  _globals['_GETUSERACCOUNTBYCOGNITOIDRESPONSE']._serialized_end=2079
  _globals['_GETUSERACCOUNTBYUSERIDREQUEST']._serialized_start=2081
  _globals['_GETUSERACCOUNTBYUSERIDREQUEST']._serialized_end=2144
  _globals['_GETUSERACCOUNTBYUSERIDRESPONSE']._serialized_start=2146
  _globals['_GETUSERACCOUNTBYUSERIDRESPONSE']._serialized_end=2230
  _globals['_GETUSERACCOUNTBYCONTACTIDREQUEST']._serialized_start=2232
  _globals['_GETUSERACCOUNTBYCONTACTIDREQUEST']._serialized_end=2301
  _globals['_GETUSERACCOUNTBYCONTACTIDRESPONSE']._serialized_start=2303
  _globals['_GETUSERACCOUNTBYCONTACTIDRESPONSE']._serialized_end=2396
  _globals['_CREATEUSERACCOUNTREQUEST']._serialized_start=2399
  _globals['_CREATEUSERACCOUNTREQUEST']._serialized_end=2669
  _globals['_CREATEUSERACCOUNTRESPONSE']._serialized_start=2671
  _globals['_CREATEUSERACCOUNTRESPONSE']._serialized_end=2750
  _globals['_UPDATEUSERACCOUNTREQUEST']._serialized_start=2753
  _globals['_UPDATEUSERACCOUNTREQUEST']._serialized_end=3011
  _globals['_UPDATEUSERACCOUNTRESPONSE']._serialized_start=3013
  _globals['_UPDATEUSERACCOUNTRESPONSE']._serialized_end=3092
  _globals['_LEGALDOCUMENT']._serialized_start=3095
  _globals['_LEGALDOCUMENT']._serialized_end=3290
  _globals['_LEGALDOCUMENTUSERAGREEMENT']._serialized_start=3293
  _globals['_LEGALDOCUMENTUSERAGREEMENT']._serialized_end=3458
  _globals['_GETALLUSERAGREEMENTSREQUEST']._serialized_start=3460
  _globals['_GETALLUSERAGREEMENTSREQUEST']._serialized_end=3521
  _globals['_GETALLUSERAGREEMENTSRESPONSE']._serialized_start=3523
  _globals['_GETALLUSERAGREEMENTSRESPONSE']._serialized_end=3618
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTREQUEST']._serialized_start=3620
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTREQUEST']._serialized_end=3735
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTRESPONSE']._serialized_start=3737
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTRESPONSE']._serialized_end=3779
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSREQUEST']._serialized_start=3781
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSREQUEST']._serialized_end=3857
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSRESPONSE']._serialized_start=3859
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSRESPONSE']._serialized_end=3969
  _globals['_LEGALDOCUMENTUSERAGREEMENTENTITY']._serialized_start=3971
  _globals['_LEGALDOCUMENTUSERAGREEMENTENTITY']._serialized_end=4069
  _globals['_ADMINUPDATEUSERREQUEST']._serialized_start=4072
  _globals['_ADMINUPDATEUSERREQUEST']._serialized_end=4543
  _globals['_ADMINUPDATEUSERRESPONSE']._serialized_start=4545
  _globals['_ADMINUPDATEUSERRESPONSE']._serialized_end=4570
  _globals['_ADMINCREATEUSERREQUEST']._serialized_start=4573
  _globals['_ADMINCREATEUSERREQUEST']._serialized_end=4830
  _globals['_ADMINCREATEUSERRESPONSE']._serialized_start=4832
  _globals['_ADMINCREATEUSERRESPONSE']._serialized_end=4857
  _globals['_ADMINCREATEINSTALLERACCOUNTREQUEST']._serialized_start=4860
  _globals['_ADMINCREATEINSTALLERACCOUNTREQUEST']._serialized_end=5071
  _globals['_ADMINCREATEINSTALLERACCOUNTRESPONSE']._serialized_start=5073
  _globals['_ADMINCREATEINSTALLERACCOUNTRESPONSE']._serialized_end=5172
  _globals['_ADMINUPDATEINSTALLERACCOUNTREQUEST']._serialized_start=5175
  _globals['_ADMINUPDATEINSTALLERACCOUNTREQUEST']._serialized_end=5403
  _globals['_ADMINUPDATEINSTALLERACCOUNTRESPONSE']._serialized_start=5405
  _globals['_ADMINUPDATEINSTALLERACCOUNTRESPONSE']._serialized_end=5504
  _globals['_ADMINFINDINSTALLERACCOUNTREQUEST']._serialized_start=5506
  _globals['_ADMINFINDINSTALLERACCOUNTREQUEST']._serialized_end=5590
  _globals['_ADMINFINDINSTALLERACCOUNTRESPONSE']._serialized_start=5592
  _globals['_ADMINFINDINSTALLERACCOUNTRESPONSE']._serialized_end=5689
  _globals['_GETUSERACCOUNTSBYHEATPUMPIDREQUEST']._serialized_start=5691
  _globals['_GETUSERACCOUNTSBYHEATPUMPIDREQUEST']._serialized_end=5764
  _globals['_GETUSERACCOUNTSBYHEATPUMPIDRESPONSE']._serialized_start=5766
  _globals['_GETUSERACCOUNTSBYHEATPUMPIDRESPONSE']._serialized_end=5855
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_start=5857
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_end=5934
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_start=5936
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_end=6019
  _globals['_HOUSEHOLD']._serialized_start=6022
  _globals['_HOUSEHOLD']._serialized_end=6206
  _globals['_HEATPUMP']._serialized_start=6208
  _globals['_HEATPUMP']._serialized_end=6249
  _globals['_RESIDENT']._serialized_start=6252
  _globals['_RESIDENT']._serialized_end=6439
  _globals['_DELETERESIDENTREQUEST']._serialized_start=6442
  _globals['_DELETERESIDENTREQUEST']._serialized_end=6603
  _globals['_DELETERESIDENTRESPONSE']._serialized_start=6605
  _globals['_DELETERESIDENTRESPONSE']._serialized_end=6633
  _globals['_GETPROXIMITYVERIFICATIONSTATUSREQUEST']._serialized_start=6635
  _globals['_GETPROXIMITYVERIFICATIONSTATUSREQUEST']._serialized_end=6674
  _globals['_GETPROXIMITYVERIFICATIONSTATUSRESPONSE']._serialized_start=6676
  _globals['_GETPROXIMITYVERIFICATIONSTATUSRESPONSE']._serialized_end=6791
  _globals['_VERIFYPROXIMITYREQUEST']._serialized_start=6793
  _globals['_VERIFYPROXIMITYREQUEST']._serialized_end=6861
  _globals['_VERIFYPROXIMITYRESPONSE']._serialized_start=6863
  _globals['_VERIFYPROXIMITYRESPONSE']._serialized_end=6921
  _globals['_USERACCOUNTSERVICE']._serialized_start=7417
  _globals['_USERACCOUNTSERVICE']._serialized_end=10205
# @@protoc_insertion_point(module_scope)