# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: schedule/v1/event.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'schedule/v1/event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import action_pb2 as schedule_dot_v1_dot_action__pb2
from . import rrule_pb2 as schedule_dot_v1_dot_rrule__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17schedule/v1/event.proto\x12\x0bschedule.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18schedule/v1/action.proto\x1a\x17schedule/v1/rrule.proto\",\n\x06\x45vents\x12\"\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x12.schedule.v1.Event\"\xa4\x03\n\x05\x45vent\x12\x33\n\x0b\x65vent_start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01\x12\x16\n\x0e\x65vent_start_dt\x18\x05 \x01(\t\x12\x36\n\tevent_end\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x02\x18\x01H\x00\x88\x01\x01\x12\x19\n\x0c\x65vent_end_dt\x18\x06 \x01(\tH\x01\x88\x01\x01\x12&\n\x05rrule\x18\x03 \x01(\x0b\x32\x12.schedule.v1.RRuleH\x02\x88\x01\x01\x12#\n\x06\x61\x63tion\x18\x04 \x01(\x0b\x32\x13.schedule.v1.Action\x12\x36\n\x0eremaining_time\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationH\x03\x88\x01\x01\x12\x13\n\x06\x61\x63tive\x18\x08 \x01(\x08H\x04\x88\x01\x01\x12\x11\n\x04name\x18\t \x01(\tH\x05\x88\x01\x01\x42\x0c\n\n_event_endB\x0f\n\r_event_end_dtB\x08\n\x06_rruleB\x11\n\x0f_remaining_timeB\t\n\x07_activeB\x07\n\x05_name\"\xee\x02\n\nEventError\x12=\n\x13missing_event_start\x18\x01 \x01(\x0b\x32\x1e.schedule.v1.MissingEventStartH\x00\x12=\n\x13invalid_event_start\x18\x02 \x01(\x0b\x32\x1e.schedule.v1.InvalidEventStartH\x00\x12\x39\n\x11invalid_event_end\x18\x03 \x01(\x0b\x32\x1c.schedule.v1.InvalidEventEndH\x00\x12\x32\n\rinvalid_rrule\x18\x04 \x01(\x0b\x32\x19.schedule.v1.InvalidRRuleH\x00\x12\x34\n\x0emissing_action\x18\x05 \x01(\x0b\x32\x1a.schedule.v1.MissingActionH\x00\x12\x34\n\x0einvalid_action\x18\x06 \x01(\x0b\x32\x1a.schedule.v1.InvalidActionH\x00\x42\x07\n\x05\x65rror\"\x13\n\x11MissingEventStart\"\x13\n\x11InvalidEventStart\"\x11\n\x0fInvalidEventEnd\"\xa0\x03\n\x0cInvalidRRule\x12\x45\n\x10invalid_argument\x18\x01 \x01(\x0b\x32).schedule.v1.InvalidRRule.InvalidArgumentH\x00\x12=\n\x0cparser_error\x18\x02 \x01(\x0b\x32%.schedule.v1.InvalidRRule.ParserErrorH\x00\x12\x45\n\x10validation_error\x18\x03 \x01(\x0b\x32).schedule.v1.InvalidRRule.ValidationErrorH\x00\x12\x39\n\niter_error\x18\x04 \x01(\x0b\x32#.schedule.v1.InvalidRRule.IterErrorH\x00\x1a\x11\n\x0fInvalidArgument\x1a\"\n\x0bParserError\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x1a&\n\x0fValidationError\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x1a \n\tIterError\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\tB\x07\n\x05\x65rror\"\x0f\n\rMissingAction\"\x0f\n\rInvalidActionBx\n\x1d\x63om.aira.contract.schedule.v1B\nEventProtoP\x01\xa2\x02\x03SXX\xaa\x02\x0bSchedule.V1\xca\x02\x0bSchedule\\V1\xe2\x02\x17Schedule\\V1\\GPBMetadata\xea\x02\x0cSchedule::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'schedule.v1.event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.aira.contract.schedule.v1B\nEventProtoP\001\242\002\003SXX\252\002\013Schedule.V1\312\002\013Schedule\\V1\342\002\027Schedule\\V1\\GPBMetadata\352\002\014Schedule::V1'
  _globals['_EVENT'].fields_by_name['event_start']._loaded_options = None
  _globals['_EVENT'].fields_by_name['event_start']._serialized_options = b'\030\001'
  _globals['_EVENT'].fields_by_name['event_end']._loaded_options = None
  _globals['_EVENT'].fields_by_name['event_end']._serialized_options = b'\030\001'
  _globals['_EVENTS']._serialized_start=156
  _globals['_EVENTS']._serialized_end=200
  _globals['_EVENT']._serialized_start=203
  _globals['_EVENT']._serialized_end=623
  _globals['_EVENTERROR']._serialized_start=626
  _globals['_EVENTERROR']._serialized_end=992
  _globals['_MISSINGEVENTSTART']._serialized_start=994
  _globals['_MISSINGEVENTSTART']._serialized_end=1013
  _globals['_INVALIDEVENTSTART']._serialized_start=1015
  _globals['_INVALIDEVENTSTART']._serialized_end=1034
  _globals['_INVALIDEVENTEND']._serialized_start=1036
  _globals['_INVALIDEVENTEND']._serialized_end=1053
  _globals['_INVALIDRRULE']._serialized_start=1056
  _globals['_INVALIDRRULE']._serialized_end=1472
  _globals['_INVALIDRRULE_INVALIDARGUMENT']._serialized_start=1336
  _globals['_INVALIDRRULE_INVALIDARGUMENT']._serialized_end=1353
  _globals['_INVALIDRRULE_PARSERERROR']._serialized_start=1355
  _globals['_INVALIDRRULE_PARSERERROR']._serialized_end=1389
  _globals['_INVALIDRRULE_VALIDATIONERROR']._serialized_start=1391
  _globals['_INVALIDRRULE_VALIDATIONERROR']._serialized_end=1429
  _globals['_INVALIDRRULE_ITERERROR']._serialized_start=1431
  _globals['_INVALIDRRULE_ITERERROR']._serialized_end=1463
  _globals['_MISSINGACTION']._serialized_start=1474
  _globals['_MISSINGACTION']._serialized_end=1489
  _globals['_INVALIDACTION']._serialized_start=1491
  _globals['_INVALIDACTION']._serialized_end=1506
# @@protoc_insertion_point(module_scope)