# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/ble/v1/main_pump_flow.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/ble/v1/main_pump_flow.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,device/heat_pump/ble/v1/main_pump_flow.proto\x12\x17\x64\x65vice.heat_pump.ble.v1\x1a\x1egoogle/protobuf/duration.proto\"\xd8\x01\n\x0cMainPumpFlow\x12=\n\x1aremaining_circulation_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x41\n\tflow_data\x18\x02 \x03(\x0b\x32..device.heat_pump.ble.v1.MainPumpFlow.FlowData\x1a\x46\n\x08\x46lowData\x12,\n\ttimestamp\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04\x66low\x18\x02 \x01(\x02\"p\n\x17GetMainPumpFlowResponse\x12\x42\n\x0emain_pump_flow\x18\x01 \x01(\x0b\x32%.device.heat_pump.ble.v1.MainPumpFlowH\x00\x88\x01\x01\x42\x11\n\x0f_main_pump_flow*\xa3\x01\n\x11MainPumpFlowState\x12$\n MAIN_PUMP_FLOW_STATE_UNSPECIFIED\x10\x00\x12$\n MAIN_PUMP_FLOW_STATE_NOT_STARTED\x10\x01\x12#\n\x1fMAIN_PUMP_FLOW_STATE_COLLECTING\x10\x02\x12\x1d\n\x19MAIN_PUMP_FLOW_STATE_DONE\x10\x03\x42\xb9\x01\n)com.aira.contract.device.heat_pump.ble.v1B\x11MainPumpFlowProtoP\x01\xa2\x02\x03\x44HB\xaa\x02\x16\x44\x65vice.HeatPump.Ble.V1\xca\x02\x16\x44\x65vice\\HeatPump\\Ble\\V1\xe2\x02\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\xea\x02\x19\x44\x65vice::HeatPump::Ble::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.ble.v1.main_pump_flow_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.aira.contract.device.heat_pump.ble.v1B\021MainPumpFlowProtoP\001\242\002\003DHB\252\002\026Device.HeatPump.Ble.V1\312\002\026Device\\HeatPump\\Ble\\V1\342\002\"Device\\HeatPump\\Ble\\V1\\GPBMetadata\352\002\031Device::HeatPump::Ble::V1'
  _globals['_MAINPUMPFLOWSTATE']._serialized_start=439
  _globals['_MAINPUMPFLOWSTATE']._serialized_end=602
  _globals['_MAINPUMPFLOW']._serialized_start=106
  _globals['_MAINPUMPFLOW']._serialized_end=322
  _globals['_MAINPUMPFLOW_FLOWDATA']._serialized_start=252
  _globals['_MAINPUMPFLOW_FLOWDATA']._serialized_end=322
  _globals['_GETMAINPUMPFLOWRESPONSE']._serialized_start=324
  _globals['_GETMAINPUMPFLOWRESPONSE']._serialized_end=436
# @@protoc_insertion_point(module_scope)